# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_facing_provider import ClientFacingProvider
from .resource_availability import ResourceAvailability


class ProviderConnectionCreated(UniversalBaseModel):
    user_id: str
    source: ClientFacingProvider = pydantic.Field()
    """
    Deprecated. Use `provider` instead. Subject to removal after 1 Jan 2024.
    """

    provider: ClientFacingProvider
    external_user_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    
    The unique identifier of the associated external data provider user.
    
    * OAuth Providers: User unique identifier; provider-specific formats
    * Password Providers: Username
    * Email Providers: Email
    * Junction Mobile SDK Providers: `null` (not available)
    """

    resource_availability: typing.Dict[str, ResourceAvailability]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SleepSummaryState(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    TENTATIVE = "tentative"
    CONFIRMED = "confirmed"

    def visit(self, tentative: typing.Callable[[], T_Result], confirmed: typing.Callable[[], T_Result]) -> T_Result:
        if self is SleepSummaryState.TENTATIVE:
            return tentative()
        if self is SleepSummaryState.CONFIRMED:
            return confirmed()



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    ActivityColumnExpr,
    ActivityColumnExprActivity,
    ActivityV2InDb,
    AddOnOrder,
    Address,
    AggregateExpr,
    AggregateExprArg,
    AggregateExprFunc,
    AggregationResponse,
    AggregationResult,
    AllowedRadius,
    Answer,
    AoE,
    AoEAnswer,
    AppointmentAvailabilitySlots,
    AppointmentBookingRequest,
    AppointmentEventStatus,
    AppointmentLocation,
    AppointmentProvider,
    AppointmentPscLabs,
    AppointmentRescheduleRequest,
    AppointmentServiceType,
    AppointmentStatus,
    AppointmentType,
    AreaInfo,
    AttemptStatus,
    AuthType,
    Availability,
    BasalBodyTemperatureEntry,
    Billing,
    BiomarkerResult,
    BodyColumnExpr,
    BodyColumnExprBody,
    BodyV2InDb,
    BulkExportConnectionsResponse,
    BulkImportConnectionsResponse,
    BulkOp,
    BulkOpStatus,
    BulkOpType,
    BulkOpsResponse,
    CervicalMucusEntry,
    CervicalMucusEntryQuality,
    ChronotypeValueMacroExpr,
    ClientActivityResponse,
    ClientBodyResponse,
    ClientFacingAFibBurdenSample,
    ClientFacingActivity,
    ClientFacingActivityChanged,
    ClientFacingActivityChangedEventType,
    ClientFacingActivityHistoricalPullCompleted,
    ClientFacingAfibBurdenChanged,
    ClientFacingAfibBurdenChangedEventType,
    ClientFacingAfibBurdenHistoricalPullCompleted,
    ClientFacingApiKey,
    ClientFacingAppointment,
    ClientFacingAppointmentCancellationReason,
    ClientFacingAppointmentChanged,
    ClientFacingAppointmentChangedEventType,
    ClientFacingAppointmentEvent,
    ClientFacingAtHomePhlebotomyOrder,
    ClientFacingAtHomePhlebotomyOrderDetails,
    ClientFacingBasalBodyTemperatureChanged,
    ClientFacingBasalBodyTemperatureChangedEventType,
    ClientFacingBasalBodyTemperatureHistoricalPullCompleted,
    ClientFacingBasalBodyTemperatureSample,
    ClientFacingBloodOxygenChanged,
    ClientFacingBloodOxygenChangedEventType,
    ClientFacingBloodOxygenHistoricalPullCompleted,
    ClientFacingBloodOxygenTimeseries,
    ClientFacingBloodPressureChanged,
    ClientFacingBloodPressureChangedEventType,
    ClientFacingBloodPressureHistoricalPullCompleted,
    ClientFacingBloodPressureTimeseries,
    ClientFacingBody,
    ClientFacingBodyChanged,
    ClientFacingBodyChangedEventType,
    ClientFacingBodyFatTimeseries,
    ClientFacingBodyHistoricalPullCompleted,
    ClientFacingBodyMassIndexChanged,
    ClientFacingBodyMassIndexChangedEventType,
    ClientFacingBodyMassIndexHistoricalPullCompleted,
    ClientFacingBodyMassIndexSample,
    ClientFacingBodyTemperatureChanged,
    ClientFacingBodyTemperatureChangedEventType,
    ClientFacingBodyTemperatureDeltaChanged,
    ClientFacingBodyTemperatureDeltaChangedEventType,
    ClientFacingBodyTemperatureDeltaHistoricalPullCompleted,
    ClientFacingBodyTemperatureDeltaSample,
    ClientFacingBodyTemperatureDeltaSampleSensorLocation,
    ClientFacingBodyTemperatureHistoricalPullCompleted,
    ClientFacingBodyTemperatureSample,
    ClientFacingBodyTemperatureSampleSensorLocation,
    ClientFacingBodyWeightTimeseries,
    ClientFacingCaffeineChanged,
    ClientFacingCaffeineChangedEventType,
    ClientFacingCaffeineHistoricalPullCompleted,
    ClientFacingCaffeineTimeseries,
    ClientFacingCaloriesActiveChanged,
    ClientFacingCaloriesActiveChangedEventType,
    ClientFacingCaloriesActiveHistoricalPullCompleted,
    ClientFacingCaloriesActiveTimeseries,
    ClientFacingCaloriesBasalChanged,
    ClientFacingCaloriesBasalChangedEventType,
    ClientFacingCaloriesBasalHistoricalPullCompleted,
    ClientFacingCaloriesBasalTimeseries,
    ClientFacingCarbohydratesChanged,
    ClientFacingCarbohydratesChangedEventType,
    ClientFacingCarbohydratesHistoricalPullCompleted,
    ClientFacingCarbohydratesSample,
    ClientFacingCholesterolChanged,
    ClientFacingCholesterolChangedEventType,
    ClientFacingCholesterolHistoricalPullCompleted,
    ClientFacingCholesterolTimeseries,
    ClientFacingConnectionErrorDetails,
    ClientFacingConnectionErrorDetailsErrorType,
    ClientFacingContinuousQueryResultTableChanged,
    ClientFacingCriticalResult,
    ClientFacingCriticalResultIdentified,
    ClientFacingDaylightExposureChanged,
    ClientFacingDaylightExposureChangedEventType,
    ClientFacingDaylightExposureHistoricalPullCompleted,
    ClientFacingDaylightExposureSample,
    ClientFacingDiagnosisInformation,
    ClientFacingDistanceChanged,
    ClientFacingDistanceChangedEventType,
    ClientFacingDistanceHistoricalPullCompleted,
    ClientFacingDistanceTimeseries,
    ClientFacingElectrocardiogram,
    ClientFacingElectrocardiogramChanged,
    ClientFacingElectrocardiogramChangedEventType,
    ClientFacingElectrocardiogramClassification,
    ClientFacingElectrocardiogramHistoricalPullCompleted,
    ClientFacingElectrocardiogramInconclusiveCause,
    ClientFacingElectrocardiogramResponse,
    ClientFacingElectrocardiogramSourceProvider,
    ClientFacingElectrocardiogramSourceType,
    ClientFacingElectrocardiogramVoltageChanged,
    ClientFacingElectrocardiogramVoltageChangedEventType,
    ClientFacingElectrocardiogramVoltageHistoricalPullCompleted,
    ClientFacingElectrocardiogramVoltageTimeseries,
    ClientFacingFallChanged,
    ClientFacingFallChangedEventType,
    ClientFacingFallHistoricalPullCompleted,
    ClientFacingFallSample,
    ClientFacingFatChanged,
    ClientFacingFatChangedEventType,
    ClientFacingFatHistoricalPullCompleted,
    ClientFacingFloorsClimbedChanged,
    ClientFacingFloorsClimbedChangedEventType,
    ClientFacingFloorsClimbedHistoricalPullCompleted,
    ClientFacingFloorsClimbedTimeseries,
    ClientFacingFood,
    ClientFacingForcedExpiratoryVolume1Changed,
    ClientFacingForcedExpiratoryVolume1ChangedEventType,
    ClientFacingForcedExpiratoryVolume1HistoricalPullCompleted,
    ClientFacingForcedExpiratoryVolume1Sample,
    ClientFacingForcedVitalCapacityChanged,
    ClientFacingForcedVitalCapacityChangedEventType,
    ClientFacingForcedVitalCapacityHistoricalPullCompleted,
    ClientFacingForcedVitalCapacitySample,
    ClientFacingGlucoseChanged,
    ClientFacingGlucoseChangedEventType,
    ClientFacingGlucoseHistoricalPullCompleted,
    ClientFacingGlucoseTimeseries,
    ClientFacingHandwashingChanged,
    ClientFacingHandwashingChangedEventType,
    ClientFacingHandwashingHistoricalPullCompleted,
    ClientFacingHandwashingSample,
    ClientFacingHeartRate,
    ClientFacingHeartRateAlertChanged,
    ClientFacingHeartRateAlertChangedEventType,
    ClientFacingHeartRateAlertHistoricalPullCompleted,
    ClientFacingHeartRateAlertSample,
    ClientFacingHeartRateAlertSampleType,
    ClientFacingHeartRateRecoveryOneMinuteChanged,
    ClientFacingHeartRateRecoveryOneMinuteChangedEventType,
    ClientFacingHeartRateRecoveryOneMinuteHistoricalPullCompleted,
    ClientFacingHeartRateRecoveryOneMinuteSample,
    ClientFacingHeartRateTimeseries,
    ClientFacingHeartrateChanged,
    ClientFacingHeartrateChangedEventType,
    ClientFacingHeartrateHistoricalPullCompleted,
    ClientFacingHrvChanged,
    ClientFacingHrvChangedEventType,
    ClientFacingHrvHistoricalPullCompleted,
    ClientFacingHrvTimeseries,
    ClientFacingHypnogramTimeseries,
    ClientFacingIgeChanged,
    ClientFacingIgeChangedEventType,
    ClientFacingIgeHistoricalPullCompleted,
    ClientFacingIgeTimeseries,
    ClientFacingIggChanged,
    ClientFacingIggChangedEventType,
    ClientFacingIggHistoricalPullCompleted,
    ClientFacingIggTimeseries,
    ClientFacingInhalerUsageChanged,
    ClientFacingInhalerUsageChangedEventType,
    ClientFacingInhalerUsageHistoricalPullCompleted,
    ClientFacingInhalerUsageSample,
    ClientFacingInsulinInjectionChanged,
    ClientFacingInsulinInjectionChangedEventType,
    ClientFacingInsulinInjectionHistoricalPullCompleted,
    ClientFacingInsulinInjectionSample,
    ClientFacingInsulinInjectionSampleType,
    ClientFacingInsurance,
    ClientFacingLab,
    ClientFacingLabLocation,
    ClientFacingLabTest,
    ClientFacingLabs,
    ClientFacingLeanBodyMassChanged,
    ClientFacingLeanBodyMassChangedEventType,
    ClientFacingLeanBodyMassHistoricalPullCompleted,
    ClientFacingLeanBodyMassSample,
    ClientFacingLoinc,
    ClientFacingMarker,
    ClientFacingMarkerComplete,
    ClientFacingMealChanged,
    ClientFacingMealChangedEventType,
    ClientFacingMealHistoricalPullCompleted,
    ClientFacingMealResponse,
    ClientFacingMenstrualCycle,
    ClientFacingMenstrualCycleChanged,
    ClientFacingMenstrualCycleChangedEventType,
    ClientFacingMenstrualCycleHistoricalPullCompleted,
    ClientFacingMenstrualCycleSourceProvider,
    ClientFacingMenstrualCycleSourceType,
    ClientFacingMindfulnessMinutesChanged,
    ClientFacingMindfulnessMinutesChangedEventType,
    ClientFacingMindfulnessMinutesHistoricalPullCompleted,
    ClientFacingMindfulnessMinutesTimeseries,
    ClientFacingNoteChanged,
    ClientFacingNoteChangedEventType,
    ClientFacingNoteHistoricalPullCompleted,
    ClientFacingNoteSample,
    ClientFacingNoteSampleTagsItem,
    ClientFacingOrder,
    ClientFacingOrderChanged,
    ClientFacingOrderChangedEventType,
    ClientFacingOrderDetails,
    ClientFacingOrderDetails_AtHomePhlebotomy,
    ClientFacingOrderDetails_Testkit,
    ClientFacingOrderDetails_WalkInTest,
    ClientFacingOrderEvent,
    ClientFacingPatientDetailsCompatible,
    ClientFacingPayorSearchResponse,
    ClientFacingPayorSearchResponseDeprecated,
    ClientFacingPeakExpiratoryFlowRateChanged,
    ClientFacingPeakExpiratoryFlowRateChangedEventType,
    ClientFacingPeakExpiratoryFlowRateHistoricalPullCompleted,
    ClientFacingPeakExpiratoryFlowRateSample,
    ClientFacingPhysician,
    ClientFacingProfile,
    ClientFacingProfileChanged,
    ClientFacingProfileChangedEventType,
    ClientFacingProfileHistoricalPullCompleted,
    ClientFacingProvider,
    ClientFacingProviderConnectionCreatedEvent,
    ClientFacingProviderConnectionErrorEvent,
    ClientFacingProviderDetailed,
    ClientFacingProviderWithStatus,
    ClientFacingResource,
    ClientFacingRespiratoryRateChanged,
    ClientFacingRespiratoryRateChangedEventType,
    ClientFacingRespiratoryRateHistoricalPullCompleted,
    ClientFacingRespiratoryRateTimeseries,
    ClientFacingResult,
    ClientFacingSampleGroupingKeys,
    ClientFacingShallowWorkoutStream,
    ClientFacingShipment,
    ClientFacingSleep,
    ClientFacingSleepApneaAlertChanged,
    ClientFacingSleepApneaAlertChangedEventType,
    ClientFacingSleepApneaAlertHistoricalPullCompleted,
    ClientFacingSleepApneaAlertSample,
    ClientFacingSleepBreathingDisturbanceChanged,
    ClientFacingSleepBreathingDisturbanceChangedEventType,
    ClientFacingSleepBreathingDisturbanceHistoricalPullCompleted,
    ClientFacingSleepBreathingDisturbanceSample,
    ClientFacingSleepBreathingDisturbanceSampleType,
    ClientFacingSleepChanged,
    ClientFacingSleepChangedEventType,
    ClientFacingSleepCycle,
    ClientFacingSleepCycleChanged,
    ClientFacingSleepCycleChangedEventType,
    ClientFacingSleepCycleHistoricalPullCompleted,
    ClientFacingSleepCycleSourceProvider,
    ClientFacingSleepCycleSourceType,
    ClientFacingSleepHistoricalPullCompleted,
    ClientFacingSleepStream,
    ClientFacingSource,
    ClientFacingSport,
    ClientFacingStandDurationChanged,
    ClientFacingStandDurationChangedEventType,
    ClientFacingStandDurationHistoricalPullCompleted,
    ClientFacingStandDurationSample,
    ClientFacingStandHourChanged,
    ClientFacingStandHourChangedEventType,
    ClientFacingStandHourHistoricalPullCompleted,
    ClientFacingStandHourSample,
    ClientFacingStandHourSampleType,
    ClientFacingStepsChanged,
    ClientFacingStepsChangedEventType,
    ClientFacingStepsHistoricalPullCompleted,
    ClientFacingStepsTimeseries,
    ClientFacingStream,
    ClientFacingStreamAltitude,
    ClientFacingStreamCadence,
    ClientFacingStreamDistance,
    ClientFacingStreamHeartrate,
    ClientFacingStreamLat,
    ClientFacingStreamLng,
    ClientFacingStreamPower,
    ClientFacingStreamResistance,
    ClientFacingStreamTemperature,
    ClientFacingStreamVelocitySmooth,
    ClientFacingStressLevelChanged,
    ClientFacingStressLevelChangedEventType,
    ClientFacingStressLevelHistoricalPullCompleted,
    ClientFacingStressLevelTimeseries,
    ClientFacingTeam,
    ClientFacingTestKitOrderDetails,
    ClientFacingTestkitOrder,
    ClientFacingUser,
    ClientFacingUserKey,
    ClientFacingUvExposureChanged,
    ClientFacingUvExposureChangedEventType,
    ClientFacingUvExposureHistoricalPullCompleted,
    ClientFacingUvExposureSample,
    ClientFacingVo2MaxChanged,
    ClientFacingVo2MaxChangedEventType,
    ClientFacingVo2MaxHistoricalPullCompleted,
    ClientFacingVo2MaxTimeseries,
    ClientFacingWaistCircumferenceChanged,
    ClientFacingWaistCircumferenceChangedEventType,
    ClientFacingWaistCircumferenceHistoricalPullCompleted,
    ClientFacingWaistCircumferenceSample,
    ClientFacingWalkInOrderDetails,
    ClientFacingWalkInTestOrder,
    ClientFacingWaterChanged,
    ClientFacingWaterChangedEventType,
    ClientFacingWaterHistoricalPullCompleted,
    ClientFacingWaterTimeseries,
    ClientFacingWeightChanged,
    ClientFacingWeightChangedEventType,
    ClientFacingWeightHistoricalPullCompleted,
    ClientFacingWheelchairPushChanged,
    ClientFacingWheelchairPushChangedEventType,
    ClientFacingWheelchairPushHistoricalPullCompleted,
    ClientFacingWheelchairPushSample,
    ClientFacingWorkout,
    ClientFacingWorkoutDistanceChanged,
    ClientFacingWorkoutDistanceChangedEventType,
    ClientFacingWorkoutDistanceHistoricalPullCompleted,
    ClientFacingWorkoutDistanceSample,
    ClientFacingWorkoutDurationChanged,
    ClientFacingWorkoutDurationChangedEventType,
    ClientFacingWorkoutDurationHistoricalPullCompleted,
    ClientFacingWorkoutDurationSample,
    ClientFacingWorkoutDurationSampleIntensity,
    ClientFacingWorkoutMap,
    ClientFacingWorkoutStreamChanged,
    ClientFacingWorkoutStreamChangedEventType,
    ClientFacingWorkoutStreamHistoricalPullCompleted,
    ClientFacingWorkoutSwimmingStrokeChanged,
    ClientFacingWorkoutSwimmingStrokeChangedEventType,
    ClientFacingWorkoutSwimmingStrokeHistoricalPullCompleted,
    ClientFacingWorkoutSwimmingStrokeSample,
    ClientFacingWorkoutsChanged,
    ClientFacingWorkoutsChangedEventType,
    ClientFacingWorkoutsHistoricalPullCompleted,
    ClientSleepCycleResponse,
    ClientSleepResponse,
    ClientUserIdConflict,
    ClientUserIdConflictResponse,
    ClientWorkoutResponse,
    ClinicalInformation,
    CompanyDetails,
    ConnectedSourceClientFacing,
    ConnectionRecipe,
    Consent,
    ConsentType,
    ContinuousQueryResultTableChanges,
    ContinuousQueryTaskHistoryEntry,
    ContinuousQueryTaskHistoryResponse,
    ContinuousQueryTaskStatus,
    ContraceptiveEntry,
    ContraceptiveEntryType,
    DatePartExpr,
    DatePartExprArg,
    DatePartExprDatePart,
    DateTruncExpr,
    DateTruncExprArg,
    DaySlots,
    DelegatedFlowType,
    DemoConnectionStatus,
    DemoProviders,
    DetectedDeviationEntry,
    DetectedDeviationEntryDeviation,
    DeviceV2InDb,
    EmailProviders,
    Energy,
    Ethnicity,
    EventDestinationPreferences,
    EventDestinationPreferencesEnabledItem,
    EventDestinationPreferencesPreferred,
    FailureType,
    FallbackBirthDate,
    FallbackTimeZone,
    Fats,
    Gender,
    GenderIdentity,
    GetMarkersResponse,
    GetOrdersResponse,
    GroupKeyColumnExpr,
    GroupKeyColumnExprGroupKey,
    GroupedAFibBurden,
    GroupedAFibBurdenResponse,
    GroupedBasalBodyTemperature,
    GroupedBasalBodyTemperatureResponse,
    GroupedBloodOxygen,
    GroupedBloodOxygenResponse,
    GroupedBloodPressure,
    GroupedBloodPressureResponse,
    GroupedBodyFat,
    GroupedBodyFatResponse,
    GroupedBodyMassIndex,
    GroupedBodyMassIndexResponse,
    GroupedBodyTemperature,
    GroupedBodyTemperatureDelta,
    GroupedBodyTemperatureDeltaResponse,
    GroupedBodyTemperatureResponse,
    GroupedBodyWeight,
    GroupedBodyWeightResponse,
    GroupedCaffeine,
    GroupedCaffeineResponse,
    GroupedCaloriesActive,
    GroupedCaloriesActiveResponse,
    GroupedCaloriesBasal,
    GroupedCaloriesBasalResponse,
    GroupedCarbohydrates,
    GroupedCarbohydratesResponse,
    GroupedCholesterol,
    GroupedCholesterolResponse,
    GroupedDaylightExposure,
    GroupedDaylightExposureResponse,
    GroupedDistance,
    GroupedDistanceResponse,
    GroupedElectrocardiogramVoltage,
    GroupedElectrocardiogramVoltageResponse,
    GroupedFall,
    GroupedFallResponse,
    GroupedFloorsClimbed,
    GroupedFloorsClimbedResponse,
    GroupedForcedExpiratoryVolume1,
    GroupedForcedExpiratoryVolume1Response,
    GroupedForcedVitalCapacity,
    GroupedForcedVitalCapacityResponse,
    GroupedGlucose,
    GroupedGlucoseResponse,
    GroupedHandwashing,
    GroupedHandwashingResponse,
    GroupedHeartRate,
    GroupedHeartRateAlert,
    GroupedHeartRateAlertResponse,
    GroupedHeartRateRecoveryOneMinute,
    GroupedHeartRateRecoveryOneMinuteResponse,
    GroupedHeartRateResponse,
    GroupedHrv,
    GroupedHrvResponse,
    GroupedHypnogram,
    GroupedHypnogramResponse,
    GroupedIge,
    GroupedIgeResponse,
    GroupedIgg,
    GroupedIggResponse,
    GroupedInhalerUsage,
    GroupedInhalerUsageResponse,
    GroupedInsulinInjection,
    GroupedInsulinInjectionResponse,
    GroupedLeanBodyMass,
    GroupedLeanBodyMassResponse,
    GroupedMindfulnessMinutes,
    GroupedMindfulnessMinutesResponse,
    GroupedNote,
    GroupedNoteResponse,
    GroupedPeakExpiratoryFlowRate,
    GroupedPeakExpiratoryFlowRateResponse,
    GroupedRespiratoryRate,
    GroupedRespiratoryRateResponse,
    GroupedSleepApneaAlert,
    GroupedSleepApneaAlertResponse,
    GroupedSleepBreathingDisturbance,
    GroupedSleepBreathingDisturbanceResponse,
    GroupedStandDuration,
    GroupedStandDurationResponse,
    GroupedStandHour,
    GroupedStandHourResponse,
    GroupedSteps,
    GroupedStepsResponse,
    GroupedStressLevel,
    GroupedStressLevelResponse,
    GroupedUvExposure,
    GroupedUvExposureResponse,
    GroupedVo2Max,
    GroupedVo2MaxResponse,
    GroupedWaistCircumference,
    GroupedWaistCircumferenceResponse,
    GroupedWater,
    GroupedWaterResponse,
    GroupedWheelchairPush,
    GroupedWheelchairPushResponse,
    GroupedWorkoutDistance,
    GroupedWorkoutDistanceResponse,
    GroupedWorkoutDuration,
    GroupedWorkoutDurationResponse,
    GroupedWorkoutSwimmingStroke,
    GroupedWorkoutSwimmingStrokeResponse,
    GuarantorDetails,
    HealthInsuranceCreateRequest,
    HealthInsuranceCreateRequestBackImage,
    HealthInsuranceCreateRequestFrontImage,
    HealthInsuranceCreateRequestPatientSignatureImage,
    HistoricalPullCompleted,
    HistoricalPullNonRetriableErrorDetails,
    HistoricalPullRetriableErrorDetails,
    HistoricalPullStatus,
    HistoricalPullTimeline,
    HomePregnancyTestEntry,
    HomePregnancyTestEntryTestResult,
    HomeProgesteroneTestEntry,
    HomeProgesteroneTestEntryTestResult,
    HttpValidationError,
    IndexColumnExpr,
    IndexColumnExprIndex,
    IntermenstrualBleedingEntry,
    Jpeg,
    LabLocationMetadata,
    LabResultsMetadata,
    LabResultsRaw,
    LabResultsRawResults,
    LabTestCollectionMethod,
    LabTestGenerationMethodFilter,
    LabTestResourcesResponse,
    LabTestSampleType,
    LabTestStatus,
    Labs,
    LastAttempt,
    LibreConfig,
    LinkTokenExchangeResponse,
    LngLat,
    Macros,
    ManualProviders,
    MarkerType,
    MealInDbBaseClientFacingSource,
    MenstrualCycleResponse,
    MenstrualFlowEntry,
    MenstrualFlowEntryFlow,
    MetricsResult,
    Micros,
    Minerals,
    MissingBiomarkerResult,
    OAuthProviders,
    OrderActivationType,
    OrderLowLevelStatus,
    OrderSetRequest,
    OrderStatus,
    OrderTopLevelStatus,
    OvulationTestEntry,
    OvulationTestEntryTestResult,
    PaginatedUsersResponse,
    ParentBiomarkerData,
    PasswordProviders,
    PatientAddress,
    PatientAddressCompatible,
    PatientAddressWithValidation,
    PatientDetailsWithValidation,
    PayorCodeExternalProvider,
    PerformingLaboratory,
    Period,
    PeriodUnit,
    PhlebotomyAreaInfo,
    PhlebotomyProviderInfo,
    PhysicianCreateRequest,
    PhysicianCreateRequestBase,
    PhysicianCreateRequestSignatureImage,
    Placeholder,
    Png,
    PostOrderResponse,
    ProfileInDb,
    ProviderConnectionCreated,
    ProviderConnectionError,
    ProviderConnectionErrorErrorType,
    ProviderLinkResponse,
    ProviderLinkResponseState,
    ProviderMfaRequest,
    ProviderMfaRequestMethod,
    Providers,
    PscAreaInfo,
    PscAreaInfoDetails,
    PscInfo,
    Query,
    QueryConfig,
    QueryConfigProviderPriorityOverridesItem,
    QueryGroupByItem,
    QuerySelectItem,
    Question,
    QuestionType,
    Race,
    RawActivity,
    RawBody,
    RawDevices,
    RawProfile,
    RawSleep,
    RawWorkout,
    Region,
    RelativeTimeframe,
    ResendWebhookResponse,
    ResourceAvailability,
    ResponsibleRelationship,
    ResultType,
    SampleData,
    SampleDataDateCollected,
    SampleDataDateReceived,
    SampleDataDateReported,
    ScopeRequirementsGrants,
    ScopeRequirementsStr,
    Select,
    SexualActivityEntry,
    SexualOrientation,
    ShippingAddress,
    ShippingAddressWithValidation,
    SingleHistoricalPullStatistics,
    SingleHistoricalPullStatisticsErrorDetails,
    SingleProviderHistoricalPullResponse,
    SingleResourceStatistics,
    SingleUserHistoricalPullResponse,
    SingleUserResourceResponse,
    SleepColumnExpr,
    SleepColumnExprSleep,
    SleepScoreValueMacroExpr,
    SleepSummaryState,
    SleepType,
    SleepV2InDb,
    Source,
    SourceAuthType,
    SourceLink,
    SourceType,
    TeamConfig,
    TimeSlot,
    TimeseriesMetricPoint,
    TimeseriesResource,
    TraceElements,
    UnrecognizedValueMacroExpr,
    UsAddress,
    UserHistoricalPullsResponse,
    UserInfo,
    UserRefreshErrorResponse,
    UserRefreshSuccessResponse,
    UserResourcesResponse,
    UserSignInTokenResponse,
    UserSuccessResponse,
    UtcTimestampWithTimezoneOffset,
    ValidationError,
    ValidationErrorLocItem,
    VitalCoreSchemasDbSchemasLabTestHealthInsurancePersonDetails,
    VitalCoreSchemasDbSchemasLabTestInsurancePersonDetails,
    VitalSleepStage,
    VitalTokenCreatedResponse,
    Vitamins,
    WorkoutColumnExpr,
    WorkoutColumnExprWorkout,
    WorkoutV2InDb,
)
from .errors import BadRequestError, UnprocessableEntityError
from . import (
    activity,
    aggregate,
    body,
    devices,
    electrocardiogram,
    insurance,
    introspect,
    lab_tests,
    link,
    meal,
    menstrual_cycle,
    order,
    profile,
    providers,
    sleep,
    sleep_cycle,
    team,
    testkit,
    user,
    vitals,
    workouts,
)
from .aggregate import QueryBatchTimeframe
from .client import AsyncVital, Vital
from .environment import VitalEnvironment
from .lab_tests import (
    LabTestsGetOrdersRequestOrderDirection,
    LabTestsGetOrdersRequestOrderKey,
    LabTestsGetPaginatedRequestOrderDirection,
    LabTestsGetPaginatedRequestOrderKey,
    LabTestsGetRequestOrderDirection,
    LabTestsGetRequestOrderKey,
)
from .version import __version__

__all__ = [
    "ActivityColumnExpr",
    "ActivityColumnExprActivity",
    "ActivityV2InDb",
    "AddOnOrder",
    "Address",
    "AggregateExpr",
    "AggregateExprArg",
    "AggregateExprFunc",
    "AggregationResponse",
    "AggregationResult",
    "AllowedRadius",
    "Answer",
    "AoE",
    "AoEAnswer",
    "AppointmentAvailabilitySlots",
    "AppointmentBookingRequest",
    "AppointmentEventStatus",
    "AppointmentLocation",
    "AppointmentProvider",
    "AppointmentPscLabs",
    "AppointmentRescheduleRequest",
    "AppointmentServiceType",
    "AppointmentStatus",
    "AppointmentType",
    "AreaInfo",
    "AsyncVital",
    "AttemptStatus",
    "AuthType",
    "Availability",
    "BadRequestError",
    "BasalBodyTemperatureEntry",
    "Billing",
    "BiomarkerResult",
    "BodyColumnExpr",
    "BodyColumnExprBody",
    "BodyV2InDb",
    "BulkExportConnectionsResponse",
    "BulkImportConnectionsResponse",
    "BulkOp",
    "BulkOpStatus",
    "BulkOpType",
    "BulkOpsResponse",
    "CervicalMucusEntry",
    "CervicalMucusEntryQuality",
    "ChronotypeValueMacroExpr",
    "ClientActivityResponse",
    "ClientBodyResponse",
    "ClientFacingAFibBurdenSample",
    "ClientFacingActivity",
    "ClientFacingActivityChanged",
    "ClientFacingActivityChangedEventType",
    "ClientFacingActivityHistoricalPullCompleted",
    "ClientFacingAfibBurdenChanged",
    "ClientFacingAfibBurdenChangedEventType",
    "ClientFacingAfibBurdenHistoricalPullCompleted",
    "ClientFacingApiKey",
    "ClientFacingAppointment",
    "ClientFacingAppointmentCancellationReason",
    "ClientFacingAppointmentChanged",
    "ClientFacingAppointmentChangedEventType",
    "ClientFacingAppointmentEvent",
    "ClientFacingAtHomePhlebotomyOrder",
    "ClientFacingAtHomePhlebotomyOrderDetails",
    "ClientFacingBasalBodyTemperatureChanged",
    "ClientFacingBasalBodyTemperatureChangedEventType",
    "ClientFacingBasalBodyTemperatureHistoricalPullCompleted",
    "ClientFacingBasalBodyTemperatureSample",
    "ClientFacingBloodOxygenChanged",
    "ClientFacingBloodOxygenChangedEventType",
    "ClientFacingBloodOxygenHistoricalPullCompleted",
    "ClientFacingBloodOxygenTimeseries",
    "ClientFacingBloodPressureChanged",
    "ClientFacingBloodPressureChangedEventType",
    "ClientFacingBloodPressureHistoricalPullCompleted",
    "ClientFacingBloodPressureTimeseries",
    "ClientFacingBody",
    "ClientFacingBodyChanged",
    "ClientFacingBodyChangedEventType",
    "ClientFacingBodyFatTimeseries",
    "ClientFacingBodyHistoricalPullCompleted",
    "ClientFacingBodyMassIndexChanged",
    "ClientFacingBodyMassIndexChangedEventType",
    "ClientFacingBodyMassIndexHistoricalPullCompleted",
    "ClientFacingBodyMassIndexSample",
    "ClientFacingBodyTemperatureChanged",
    "ClientFacingBodyTemperatureChangedEventType",
    "ClientFacingBodyTemperatureDeltaChanged",
    "ClientFacingBodyTemperatureDeltaChangedEventType",
    "ClientFacingBodyTemperatureDeltaHistoricalPullCompleted",
    "ClientFacingBodyTemperatureDeltaSample",
    "ClientFacingBodyTemperatureDeltaSampleSensorLocation",
    "ClientFacingBodyTemperatureHistoricalPullCompleted",
    "ClientFacingBodyTemperatureSample",
    "ClientFacingBodyTemperatureSampleSensorLocation",
    "ClientFacingBodyWeightTimeseries",
    "ClientFacingCaffeineChanged",
    "ClientFacingCaffeineChangedEventType",
    "ClientFacingCaffeineHistoricalPullCompleted",
    "ClientFacingCaffeineTimeseries",
    "ClientFacingCaloriesActiveChanged",
    "ClientFacingCaloriesActiveChangedEventType",
    "ClientFacingCaloriesActiveHistoricalPullCompleted",
    "ClientFacingCaloriesActiveTimeseries",
    "ClientFacingCaloriesBasalChanged",
    "ClientFacingCaloriesBasalChangedEventType",
    "ClientFacingCaloriesBasalHistoricalPullCompleted",
    "ClientFacingCaloriesBasalTimeseries",
    "ClientFacingCarbohydratesChanged",
    "ClientFacingCarbohydratesChangedEventType",
    "ClientFacingCarbohydratesHistoricalPullCompleted",
    "ClientFacingCarbohydratesSample",
    "ClientFacingCholesterolChanged",
    "ClientFacingCholesterolChangedEventType",
    "ClientFacingCholesterolHistoricalPullCompleted",
    "ClientFacingCholesterolTimeseries",
    "ClientFacingConnectionErrorDetails",
    "ClientFacingConnectionErrorDetailsErrorType",
    "ClientFacingContinuousQueryResultTableChanged",
    "ClientFacingCriticalResult",
    "ClientFacingCriticalResultIdentified",
    "ClientFacingDaylightExposureChanged",
    "ClientFacingDaylightExposureChangedEventType",
    "ClientFacingDaylightExposureHistoricalPullCompleted",
    "ClientFacingDaylightExposureSample",
    "ClientFacingDiagnosisInformation",
    "ClientFacingDistanceChanged",
    "ClientFacingDistanceChangedEventType",
    "ClientFacingDistanceHistoricalPullCompleted",
    "ClientFacingDistanceTimeseries",
    "ClientFacingElectrocardiogram",
    "ClientFacingElectrocardiogramChanged",
    "ClientFacingElectrocardiogramChangedEventType",
    "ClientFacingElectrocardiogramClassification",
    "ClientFacingElectrocardiogramHistoricalPullCompleted",
    "ClientFacingElectrocardiogramInconclusiveCause",
    "ClientFacingElectrocardiogramResponse",
    "ClientFacingElectrocardiogramSourceProvider",
    "ClientFacingElectrocardiogramSourceType",
    "ClientFacingElectrocardiogramVoltageChanged",
    "ClientFacingElectrocardiogramVoltageChangedEventType",
    "ClientFacingElectrocardiogramVoltageHistoricalPullCompleted",
    "ClientFacingElectrocardiogramVoltageTimeseries",
    "ClientFacingFallChanged",
    "ClientFacingFallChangedEventType",
    "ClientFacingFallHistoricalPullCompleted",
    "ClientFacingFallSample",
    "ClientFacingFatChanged",
    "ClientFacingFatChangedEventType",
    "ClientFacingFatHistoricalPullCompleted",
    "ClientFacingFloorsClimbedChanged",
    "ClientFacingFloorsClimbedChangedEventType",
    "ClientFacingFloorsClimbedHistoricalPullCompleted",
    "ClientFacingFloorsClimbedTimeseries",
    "ClientFacingFood",
    "ClientFacingForcedExpiratoryVolume1Changed",
    "ClientFacingForcedExpiratoryVolume1ChangedEventType",
    "ClientFacingForcedExpiratoryVolume1HistoricalPullCompleted",
    "ClientFacingForcedExpiratoryVolume1Sample",
    "ClientFacingForcedVitalCapacityChanged",
    "ClientFacingForcedVitalCapacityChangedEventType",
    "ClientFacingForcedVitalCapacityHistoricalPullCompleted",
    "ClientFacingForcedVitalCapacitySample",
    "ClientFacingGlucoseChanged",
    "ClientFacingGlucoseChangedEventType",
    "ClientFacingGlucoseHistoricalPullCompleted",
    "ClientFacingGlucoseTimeseries",
    "ClientFacingHandwashingChanged",
    "ClientFacingHandwashingChangedEventType",
    "ClientFacingHandwashingHistoricalPullCompleted",
    "ClientFacingHandwashingSample",
    "ClientFacingHeartRate",
    "ClientFacingHeartRateAlertChanged",
    "ClientFacingHeartRateAlertChangedEventType",
    "ClientFacingHeartRateAlertHistoricalPullCompleted",
    "ClientFacingHeartRateAlertSample",
    "ClientFacingHeartRateAlertSampleType",
    "ClientFacingHeartRateRecoveryOneMinuteChanged",
    "ClientFacingHeartRateRecoveryOneMinuteChangedEventType",
    "ClientFacingHeartRateRecoveryOneMinuteHistoricalPullCompleted",
    "ClientFacingHeartRateRecoveryOneMinuteSample",
    "ClientFacingHeartRateTimeseries",
    "ClientFacingHeartrateChanged",
    "ClientFacingHeartrateChangedEventType",
    "ClientFacingHeartrateHistoricalPullCompleted",
    "ClientFacingHrvChanged",
    "ClientFacingHrvChangedEventType",
    "ClientFacingHrvHistoricalPullCompleted",
    "ClientFacingHrvTimeseries",
    "ClientFacingHypnogramTimeseries",
    "ClientFacingIgeChanged",
    "ClientFacingIgeChangedEventType",
    "ClientFacingIgeHistoricalPullCompleted",
    "ClientFacingIgeTimeseries",
    "ClientFacingIggChanged",
    "ClientFacingIggChangedEventType",
    "ClientFacingIggHistoricalPullCompleted",
    "ClientFacingIggTimeseries",
    "ClientFacingInhalerUsageChanged",
    "ClientFacingInhalerUsageChangedEventType",
    "ClientFacingInhalerUsageHistoricalPullCompleted",
    "ClientFacingInhalerUsageSample",
    "ClientFacingInsulinInjectionChanged",
    "ClientFacingInsulinInjectionChangedEventType",
    "ClientFacingInsulinInjectionHistoricalPullCompleted",
    "ClientFacingInsulinInjectionSample",
    "ClientFacingInsulinInjectionSampleType",
    "ClientFacingInsurance",
    "ClientFacingLab",
    "ClientFacingLabLocation",
    "ClientFacingLabTest",
    "ClientFacingLabs",
    "ClientFacingLeanBodyMassChanged",
    "ClientFacingLeanBodyMassChangedEventType",
    "ClientFacingLeanBodyMassHistoricalPullCompleted",
    "ClientFacingLeanBodyMassSample",
    "ClientFacingLoinc",
    "ClientFacingMarker",
    "ClientFacingMarkerComplete",
    "ClientFacingMealChanged",
    "ClientFacingMealChangedEventType",
    "ClientFacingMealHistoricalPullCompleted",
    "ClientFacingMealResponse",
    "ClientFacingMenstrualCycle",
    "ClientFacingMenstrualCycleChanged",
    "ClientFacingMenstrualCycleChangedEventType",
    "ClientFacingMenstrualCycleHistoricalPullCompleted",
    "ClientFacingMenstrualCycleSourceProvider",
    "ClientFacingMenstrualCycleSourceType",
    "ClientFacingMindfulnessMinutesChanged",
    "ClientFacingMindfulnessMinutesChangedEventType",
    "ClientFacingMindfulnessMinutesHistoricalPullCompleted",
    "ClientFacingMindfulnessMinutesTimeseries",
    "ClientFacingNoteChanged",
    "ClientFacingNoteChangedEventType",
    "ClientFacingNoteHistoricalPullCompleted",
    "ClientFacingNoteSample",
    "ClientFacingNoteSampleTagsItem",
    "ClientFacingOrder",
    "ClientFacingOrderChanged",
    "ClientFacingOrderChangedEventType",
    "ClientFacingOrderDetails",
    "ClientFacingOrderDetails_AtHomePhlebotomy",
    "ClientFacingOrderDetails_Testkit",
    "ClientFacingOrderDetails_WalkInTest",
    "ClientFacingOrderEvent",
    "ClientFacingPatientDetailsCompatible",
    "ClientFacingPayorSearchResponse",
    "ClientFacingPayorSearchResponseDeprecated",
    "ClientFacingPeakExpiratoryFlowRateChanged",
    "ClientFacingPeakExpiratoryFlowRateChangedEventType",
    "ClientFacingPeakExpiratoryFlowRateHistoricalPullCompleted",
    "ClientFacingPeakExpiratoryFlowRateSample",
    "ClientFacingPhysician",
    "ClientFacingProfile",
    "ClientFacingProfileChanged",
    "ClientFacingProfileChangedEventType",
    "ClientFacingProfileHistoricalPullCompleted",
    "ClientFacingProvider",
    "ClientFacingProviderConnectionCreatedEvent",
    "ClientFacingProviderConnectionErrorEvent",
    "ClientFacingProviderDetailed",
    "ClientFacingProviderWithStatus",
    "ClientFacingResource",
    "ClientFacingRespiratoryRateChanged",
    "ClientFacingRespiratoryRateChangedEventType",
    "ClientFacingRespiratoryRateHistoricalPullCompleted",
    "ClientFacingRespiratoryRateTimeseries",
    "ClientFacingResult",
    "ClientFacingSampleGroupingKeys",
    "ClientFacingShallowWorkoutStream",
    "ClientFacingShipment",
    "ClientFacingSleep",
    "ClientFacingSleepApneaAlertChanged",
    "ClientFacingSleepApneaAlertChangedEventType",
    "ClientFacingSleepApneaAlertHistoricalPullCompleted",
    "ClientFacingSleepApneaAlertSample",
    "ClientFacingSleepBreathingDisturbanceChanged",
    "ClientFacingSleepBreathingDisturbanceChangedEventType",
    "ClientFacingSleepBreathingDisturbanceHistoricalPullCompleted",
    "ClientFacingSleepBreathingDisturbanceSample",
    "ClientFacingSleepBreathingDisturbanceSampleType",
    "ClientFacingSleepChanged",
    "ClientFacingSleepChangedEventType",
    "ClientFacingSleepCycle",
    "ClientFacingSleepCycleChanged",
    "ClientFacingSleepCycleChangedEventType",
    "ClientFacingSleepCycleHistoricalPullCompleted",
    "ClientFacingSleepCycleSourceProvider",
    "ClientFacingSleepCycleSourceType",
    "ClientFacingSleepHistoricalPullCompleted",
    "ClientFacingSleepStream",
    "ClientFacingSource",
    "ClientFacingSport",
    "ClientFacingStandDurationChanged",
    "ClientFacingStandDurationChangedEventType",
    "ClientFacingStandDurationHistoricalPullCompleted",
    "ClientFacingStandDurationSample",
    "ClientFacingStandHourChanged",
    "ClientFacingStandHourChangedEventType",
    "ClientFacingStandHourHistoricalPullCompleted",
    "ClientFacingStandHourSample",
    "ClientFacingStandHourSampleType",
    "ClientFacingStepsChanged",
    "ClientFacingStepsChangedEventType",
    "ClientFacingStepsHistoricalPullCompleted",
    "ClientFacingStepsTimeseries",
    "ClientFacingStream",
    "ClientFacingStreamAltitude",
    "ClientFacingStreamCadence",
    "ClientFacingStreamDistance",
    "ClientFacingStreamHeartrate",
    "ClientFacingStreamLat",
    "ClientFacingStreamLng",
    "ClientFacingStreamPower",
    "ClientFacingStreamResistance",
    "ClientFacingStreamTemperature",
    "ClientFacingStreamVelocitySmooth",
    "ClientFacingStressLevelChanged",
    "ClientFacingStressLevelChangedEventType",
    "ClientFacingStressLevelHistoricalPullCompleted",
    "ClientFacingStressLevelTimeseries",
    "ClientFacingTeam",
    "ClientFacingTestKitOrderDetails",
    "ClientFacingTestkitOrder",
    "ClientFacingUser",
    "ClientFacingUserKey",
    "ClientFacingUvExposureChanged",
    "ClientFacingUvExposureChangedEventType",
    "ClientFacingUvExposureHistoricalPullCompleted",
    "ClientFacingUvExposureSample",
    "ClientFacingVo2MaxChanged",
    "ClientFacingVo2MaxChangedEventType",
    "ClientFacingVo2MaxHistoricalPullCompleted",
    "ClientFacingVo2MaxTimeseries",
    "ClientFacingWaistCircumferenceChanged",
    "ClientFacingWaistCircumferenceChangedEventType",
    "ClientFacingWaistCircumferenceHistoricalPullCompleted",
    "ClientFacingWaistCircumferenceSample",
    "ClientFacingWalkInOrderDetails",
    "ClientFacingWalkInTestOrder",
    "ClientFacingWaterChanged",
    "ClientFacingWaterChangedEventType",
    "ClientFacingWaterHistoricalPullCompleted",
    "ClientFacingWaterTimeseries",
    "ClientFacingWeightChanged",
    "ClientFacingWeightChangedEventType",
    "ClientFacingWeightHistoricalPullCompleted",
    "ClientFacingWheelchairPushChanged",
    "ClientFacingWheelchairPushChangedEventType",
    "ClientFacingWheelchairPushHistoricalPullCompleted",
    "ClientFacingWheelchairPushSample",
    "ClientFacingWorkout",
    "ClientFacingWorkoutDistanceChanged",
    "ClientFacingWorkoutDistanceChangedEventType",
    "ClientFacingWorkoutDistanceHistoricalPullCompleted",
    "ClientFacingWorkoutDistanceSample",
    "ClientFacingWorkoutDurationChanged",
    "ClientFacingWorkoutDurationChangedEventType",
    "ClientFacingWorkoutDurationHistoricalPullCompleted",
    "ClientFacingWorkoutDurationSample",
    "ClientFacingWorkoutDurationSampleIntensity",
    "ClientFacingWorkoutMap",
    "ClientFacingWorkoutStreamChanged",
    "ClientFacingWorkoutStreamChangedEventType",
    "ClientFacingWorkoutStreamHistoricalPullCompleted",
    "ClientFacingWorkoutSwimmingStrokeChanged",
    "ClientFacingWorkoutSwimmingStrokeChangedEventType",
    "ClientFacingWorkoutSwimmingStrokeHistoricalPullCompleted",
    "ClientFacingWorkoutSwimmingStrokeSample",
    "ClientFacingWorkoutsChanged",
    "ClientFacingWorkoutsChangedEventType",
    "ClientFacingWorkoutsHistoricalPullCompleted",
    "ClientSleepCycleResponse",
    "ClientSleepResponse",
    "ClientUserIdConflict",
    "ClientUserIdConflictResponse",
    "ClientWorkoutResponse",
    "ClinicalInformation",
    "CompanyDetails",
    "ConnectedSourceClientFacing",
    "ConnectionRecipe",
    "Consent",
    "ConsentType",
    "ContinuousQueryResultTableChanges",
    "ContinuousQueryTaskHistoryEntry",
    "ContinuousQueryTaskHistoryResponse",
    "ContinuousQueryTaskStatus",
    "ContraceptiveEntry",
    "ContraceptiveEntryType",
    "DatePartExpr",
    "DatePartExprArg",
    "DatePartExprDatePart",
    "DateTruncExpr",
    "DateTruncExprArg",
    "DaySlots",
    "DelegatedFlowType",
    "DemoConnectionStatus",
    "DemoProviders",
    "DetectedDeviationEntry",
    "DetectedDeviationEntryDeviation",
    "DeviceV2InDb",
    "EmailProviders",
    "Energy",
    "Ethnicity",
    "EventDestinationPreferences",
    "EventDestinationPreferencesEnabledItem",
    "EventDestinationPreferencesPreferred",
    "FailureType",
    "FallbackBirthDate",
    "FallbackTimeZone",
    "Fats",
    "Gender",
    "GenderIdentity",
    "GetMarkersResponse",
    "GetOrdersResponse",
    "GroupKeyColumnExpr",
    "GroupKeyColumnExprGroupKey",
    "GroupedAFibBurden",
    "GroupedAFibBurdenResponse",
    "GroupedBasalBodyTemperature",
    "GroupedBasalBodyTemperatureResponse",
    "GroupedBloodOxygen",
    "GroupedBloodOxygenResponse",
    "GroupedBloodPressure",
    "GroupedBloodPressureResponse",
    "GroupedBodyFat",
    "GroupedBodyFatResponse",
    "GroupedBodyMassIndex",
    "GroupedBodyMassIndexResponse",
    "GroupedBodyTemperature",
    "GroupedBodyTemperatureDelta",
    "GroupedBodyTemperatureDeltaResponse",
    "GroupedBodyTemperatureResponse",
    "GroupedBodyWeight",
    "GroupedBodyWeightResponse",
    "GroupedCaffeine",
    "GroupedCaffeineResponse",
    "GroupedCaloriesActive",
    "GroupedCaloriesActiveResponse",
    "GroupedCaloriesBasal",
    "GroupedCaloriesBasalResponse",
    "GroupedCarbohydrates",
    "GroupedCarbohydratesResponse",
    "GroupedCholesterol",
    "GroupedCholesterolResponse",
    "GroupedDaylightExposure",
    "GroupedDaylightExposureResponse",
    "GroupedDistance",
    "GroupedDistanceResponse",
    "GroupedElectrocardiogramVoltage",
    "GroupedElectrocardiogramVoltageResponse",
    "GroupedFall",
    "GroupedFallResponse",
    "GroupedFloorsClimbed",
    "GroupedFloorsClimbedResponse",
    "GroupedForcedExpiratoryVolume1",
    "GroupedForcedExpiratoryVolume1Response",
    "GroupedForcedVitalCapacity",
    "GroupedForcedVitalCapacityResponse",
    "GroupedGlucose",
    "GroupedGlucoseResponse",
    "GroupedHandwashing",
    "GroupedHandwashingResponse",
    "GroupedHeartRate",
    "GroupedHeartRateAlert",
    "GroupedHeartRateAlertResponse",
    "GroupedHeartRateRecoveryOneMinute",
    "GroupedHeartRateRecoveryOneMinuteResponse",
    "GroupedHeartRateResponse",
    "GroupedHrv",
    "GroupedHrvResponse",
    "GroupedHypnogram",
    "GroupedHypnogramResponse",
    "GroupedIge",
    "GroupedIgeResponse",
    "GroupedIgg",
    "GroupedIggResponse",
    "GroupedInhalerUsage",
    "GroupedInhalerUsageResponse",
    "GroupedInsulinInjection",
    "GroupedInsulinInjectionResponse",
    "GroupedLeanBodyMass",
    "GroupedLeanBodyMassResponse",
    "GroupedMindfulnessMinutes",
    "GroupedMindfulnessMinutesResponse",
    "GroupedNote",
    "GroupedNoteResponse",
    "GroupedPeakExpiratoryFlowRate",
    "GroupedPeakExpiratoryFlowRateResponse",
    "GroupedRespiratoryRate",
    "GroupedRespiratoryRateResponse",
    "GroupedSleepApneaAlert",
    "GroupedSleepApneaAlertResponse",
    "GroupedSleepBreathingDisturbance",
    "GroupedSleepBreathingDisturbanceResponse",
    "GroupedStandDuration",
    "GroupedStandDurationResponse",
    "GroupedStandHour",
    "GroupedStandHourResponse",
    "GroupedSteps",
    "GroupedStepsResponse",
    "GroupedStressLevel",
    "GroupedStressLevelResponse",
    "GroupedUvExposure",
    "GroupedUvExposureResponse",
    "GroupedVo2Max",
    "GroupedVo2MaxResponse",
    "GroupedWaistCircumference",
    "GroupedWaistCircumferenceResponse",
    "GroupedWater",
    "GroupedWaterResponse",
    "GroupedWheelchairPush",
    "GroupedWheelchairPushResponse",
    "GroupedWorkoutDistance",
    "GroupedWorkoutDistanceResponse",
    "GroupedWorkoutDuration",
    "GroupedWorkoutDurationResponse",
    "GroupedWorkoutSwimmingStroke",
    "GroupedWorkoutSwimmingStrokeResponse",
    "GuarantorDetails",
    "HealthInsuranceCreateRequest",
    "HealthInsuranceCreateRequestBackImage",
    "HealthInsuranceCreateRequestFrontImage",
    "HealthInsuranceCreateRequestPatientSignatureImage",
    "HistoricalPullCompleted",
    "HistoricalPullNonRetriableErrorDetails",
    "HistoricalPullRetriableErrorDetails",
    "HistoricalPullStatus",
    "HistoricalPullTimeline",
    "HomePregnancyTestEntry",
    "HomePregnancyTestEntryTestResult",
    "HomeProgesteroneTestEntry",
    "HomeProgesteroneTestEntryTestResult",
    "HttpValidationError",
    "IndexColumnExpr",
    "IndexColumnExprIndex",
    "IntermenstrualBleedingEntry",
    "Jpeg",
    "LabLocationMetadata",
    "LabResultsMetadata",
    "LabResultsRaw",
    "LabResultsRawResults",
    "LabTestCollectionMethod",
    "LabTestGenerationMethodFilter",
    "LabTestResourcesResponse",
    "LabTestSampleType",
    "LabTestStatus",
    "LabTestsGetOrdersRequestOrderDirection",
    "LabTestsGetOrdersRequestOrderKey",
    "LabTestsGetPaginatedRequestOrderDirection",
    "LabTestsGetPaginatedRequestOrderKey",
    "LabTestsGetRequestOrderDirection",
    "LabTestsGetRequestOrderKey",
    "Labs",
    "LastAttempt",
    "LibreConfig",
    "LinkTokenExchangeResponse",
    "LngLat",
    "Macros",
    "ManualProviders",
    "MarkerType",
    "MealInDbBaseClientFacingSource",
    "MenstrualCycleResponse",
    "MenstrualFlowEntry",
    "MenstrualFlowEntryFlow",
    "MetricsResult",
    "Micros",
    "Minerals",
    "MissingBiomarkerResult",
    "OAuthProviders",
    "OrderActivationType",
    "OrderLowLevelStatus",
    "OrderSetRequest",
    "OrderStatus",
    "OrderTopLevelStatus",
    "OvulationTestEntry",
    "OvulationTestEntryTestResult",
    "PaginatedUsersResponse",
    "ParentBiomarkerData",
    "PasswordProviders",
    "PatientAddress",
    "PatientAddressCompatible",
    "PatientAddressWithValidation",
    "PatientDetailsWithValidation",
    "PayorCodeExternalProvider",
    "PerformingLaboratory",
    "Period",
    "PeriodUnit",
    "PhlebotomyAreaInfo",
    "PhlebotomyProviderInfo",
    "PhysicianCreateRequest",
    "PhysicianCreateRequestBase",
    "PhysicianCreateRequestSignatureImage",
    "Placeholder",
    "Png",
    "PostOrderResponse",
    "ProfileInDb",
    "ProviderConnectionCreated",
    "ProviderConnectionError",
    "ProviderConnectionErrorErrorType",
    "ProviderLinkResponse",
    "ProviderLinkResponseState",
    "ProviderMfaRequest",
    "ProviderMfaRequestMethod",
    "Providers",
    "PscAreaInfo",
    "PscAreaInfoDetails",
    "PscInfo",
    "Query",
    "QueryBatchTimeframe",
    "QueryConfig",
    "QueryConfigProviderPriorityOverridesItem",
    "QueryGroupByItem",
    "QuerySelectItem",
    "Question",
    "QuestionType",
    "Race",
    "RawActivity",
    "RawBody",
    "RawDevices",
    "RawProfile",
    "RawSleep",
    "RawWorkout",
    "Region",
    "RelativeTimeframe",
    "ResendWebhookResponse",
    "ResourceAvailability",
    "ResponsibleRelationship",
    "ResultType",
    "SampleData",
    "SampleDataDateCollected",
    "SampleDataDateReceived",
    "SampleDataDateReported",
    "ScopeRequirementsGrants",
    "ScopeRequirementsStr",
    "Select",
    "SexualActivityEntry",
    "SexualOrientation",
    "ShippingAddress",
    "ShippingAddressWithValidation",
    "SingleHistoricalPullStatistics",
    "SingleHistoricalPullStatisticsErrorDetails",
    "SingleProviderHistoricalPullResponse",
    "SingleResourceStatistics",
    "SingleUserHistoricalPullResponse",
    "SingleUserResourceResponse",
    "SleepColumnExpr",
    "SleepColumnExprSleep",
    "SleepScoreValueMacroExpr",
    "SleepSummaryState",
    "SleepType",
    "SleepV2InDb",
    "Source",
    "SourceAuthType",
    "SourceLink",
    "SourceType",
    "TeamConfig",
    "TimeSlot",
    "TimeseriesMetricPoint",
    "TimeseriesResource",
    "TraceElements",
    "UnprocessableEntityError",
    "UnrecognizedValueMacroExpr",
    "UsAddress",
    "UserHistoricalPullsResponse",
    "UserInfo",
    "UserRefreshErrorResponse",
    "UserRefreshSuccessResponse",
    "UserResourcesResponse",
    "UserSignInTokenResponse",
    "UserSuccessResponse",
    "UtcTimestampWithTimezoneOffset",
    "ValidationError",
    "ValidationErrorLocItem",
    "Vital",
    "VitalCoreSchemasDbSchemasLabTestHealthInsurancePersonDetails",
    "VitalCoreSchemasDbSchemasLabTestInsurancePersonDetails",
    "VitalEnvironment",
    "VitalSleepStage",
    "VitalTokenCreatedResponse",
    "Vitamins",
    "WorkoutColumnExpr",
    "WorkoutColumnExprWorkout",
    "WorkoutV2InDb",
    "__version__",
    "activity",
    "aggregate",
    "body",
    "devices",
    "electrocardiogram",
    "insurance",
    "introspect",
    "lab_tests",
    "link",
    "meal",
    "menstrual_cycle",
    "order",
    "profile",
    "providers",
    "sleep",
    "sleep_cycle",
    "team",
    "testkit",
    "user",
    "vitals",
    "workouts",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class CervicalMucusEntryQuality(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    DRY = "dry"
    STICKY = "sticky"
    CREAMY = "creamy"
    WATERY = "watery"
    EGG_WHITE = "egg_white"

    def visit(
        self,
        dry: typing.Callable[[], T_Result],
        sticky: typing.Callable[[], T_Result],
        creamy: typing.Callable[[], T_Result],
        watery: typing.Callable[[], T_Result],
        egg_white: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is CervicalMucusEntryQuality.DRY:
            return dry()
        if self is CervicalMucusEntryQuality.STICKY:
            return sticky()
        if self is CervicalMucusEntryQuality.CREAMY:
            return creamy()
        if self is CervicalMucusEntryQuality.WATERY:
            return watery()
        if self is CervicalMucusEntryQuality.EGG_WHITE:
            return egg_white()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_facing_source import ClientFacingSource


class ClientFacingProfile(UniversalBaseModel):
    id: str
    user_id: str = pydantic.Field()
    """
    User id returned by vital create user request. This id should be stored in your database against the user and used for all interactions with the vital api.
    """

    height: typing.Optional[int] = None
    birth_date: typing.Optional[str] = None
    wheelchair_use: typing.Optional[bool] = None
    source: ClientFacingSource
    created_at: dt.datetime
    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabTestStatus(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    ACTIVE = "active"
    PENDING_APPROVAL = "pending_approval"
    INACTIVE = "inactive"

    def visit(
        self,
        active: typing.Callable[[], T_Result],
        pending_approval: typing.Callable[[], T_Result],
        inactive: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LabTestStatus.ACTIVE:
            return active()
        if self is LabTestStatus.PENDING_APPROVAL:
            return pending_approval()
        if self is LabTestStatus.INACTIVE:
            return inactive()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SexualOrientation(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    LESBIAN_GAY_OR_HOMOSEXUAL = "lesbian_gay_or_homosexual"
    HETEROSEXUAL_OR_STRAIGHT = "heterosexual_or_straight"
    BISEXUAL = "bisexual"
    DONT_KNOW = "dont_know"
    OTHER = "other"

    def visit(
        self,
        lesbian_gay_or_homosexual: typing.Callable[[], T_Result],
        heterosexual_or_straight: typing.Callable[[], T_Result],
        bisexual: typing.Callable[[], T_Result],
        dont_know: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is SexualOrientation.LESBIAN_GAY_OR_HOMOSEXUAL:
            return lesbian_gay_or_homosexual()
        if self is SexualOrientation.HETEROSEXUAL_OR_STRAIGHT:
            return heterosexual_or_straight()
        if self is SexualOrientation.BISEXUAL:
            return bisexual()
        if self is SexualOrientation.DONT_KNOW:
            return dont_know()
        if self is SexualOrientation.OTHER:
            return other()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OrderLowLevelStatus(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    ORDERED = "ordered"
    REQUISITION_CREATED = "requisition_created"
    REQUISITION_BYPASSED = "requisition_bypassed"
    TRANSIT_CUSTOMER = "transit_customer"
    OUT_FOR_DELIVERY = "out_for_delivery"
    WITH_CUSTOMER = "with_customer"
    TRANSIT_LAB = "transit_lab"
    DELIVERED_TO_LAB = "delivered_to_lab"
    COMPLETED = "completed"
    FAILURE_TO_DELIVER_TO_LAB = "failure_to_deliver_to_lab"
    FAILURE_TO_DELIVER_TO_CUSTOMER = "failure_to_deliver_to_customer"
    PROBLEM_IN_TRANSIT_LAB = "problem_in_transit_lab"
    PROBLEM_IN_TRANSIT_CUSTOMER = "problem_in_transit_customer"
    SAMPLE_ERROR = "sample_error"
    APPOINTMENT_SCHEDULED = "appointment_scheduled"
    APPOINTMENT_CANCELLED = "appointment_cancelled"
    APPOINTMENT_PENDING = "appointment_pending"
    DRAW_COMPLETED = "draw_completed"
    CANCELLED = "cancelled"
    LOST = "lost"
    DO_NOT_PROCESS = "do_not_process"
    PARTIAL_RESULTS = "partial_results"
    AWAITING_REGISTRATION = "awaiting_registration"
    REGISTERED = "registered"

    def visit(
        self,
        ordered: typing.Callable[[], T_Result],
        requisition_created: typing.Callable[[], T_Result],
        requisition_bypassed: typing.Callable[[], T_Result],
        transit_customer: typing.Callable[[], T_Result],
        out_for_delivery: typing.Callable[[], T_Result],
        with_customer: typing.Callable[[], T_Result],
        transit_lab: typing.Callable[[], T_Result],
        delivered_to_lab: typing.Callable[[], T_Result],
        completed: typing.Callable[[], T_Result],
        failure_to_deliver_to_lab: typing.Callable[[], T_Result],
        failure_to_deliver_to_customer: typing.Callable[[], T_Result],
        problem_in_transit_lab: typing.Callable[[], T_Result],
        problem_in_transit_customer: typing.Callable[[], T_Result],
        sample_error: typing.Callable[[], T_Result],
        appointment_scheduled: typing.Callable[[], T_Result],
        appointment_cancelled: typing.Callable[[], T_Result],
        appointment_pending: typing.Callable[[], T_Result],
        draw_completed: typing.Callable[[], T_Result],
        cancelled: typing.Callable[[], T_Result],
        lost: typing.Callable[[], T_Result],
        do_not_process: typing.Callable[[], T_Result],
        partial_results: typing.Callable[[], T_Result],
        awaiting_registration: typing.Callable[[], T_Result],
        registered: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is OrderLowLevelStatus.ORDERED:
            return ordered()
        if self is OrderLowLevelStatus.REQUISITION_CREATED:
            return requisition_created()
        if self is OrderLowLevelStatus.REQUISITION_BYPASSED:
            return requisition_bypassed()
        if self is OrderLowLevelStatus.TRANSIT_CUSTOMER:
            return transit_customer()
        if self is OrderLowLevelStatus.OUT_FOR_DELIVERY:
            return out_for_delivery()
        if self is OrderLowLevelStatus.WITH_CUSTOMER:
            return with_customer()
        if self is OrderLowLevelStatus.TRANSIT_LAB:
            return transit_lab()
        if self is OrderLowLevelStatus.DELIVERED_TO_LAB:
            return delivered_to_lab()
        if self is OrderLowLevelStatus.COMPLETED:
            return completed()
        if self is OrderLowLevelStatus.FAILURE_TO_DELIVER_TO_LAB:
            return failure_to_deliver_to_lab()
        if self is OrderLowLevelStatus.FAILURE_TO_DELIVER_TO_CUSTOMER:
            return failure_to_deliver_to_customer()
        if self is OrderLowLevelStatus.PROBLEM_IN_TRANSIT_LAB:
            return problem_in_transit_lab()
        if self is OrderLowLevelStatus.PROBLEM_IN_TRANSIT_CUSTOMER:
            return problem_in_transit_customer()
        if self is OrderLowLevelStatus.SAMPLE_ERROR:
            return sample_error()
        if self is OrderLowLevelStatus.APPOINTMENT_SCHEDULED:
            return appointment_scheduled()
        if self is OrderLowLevelStatus.APPOINTMENT_CANCELLED:
            return appointment_cancelled()
        if self is OrderLowLevelStatus.APPOINTMENT_PENDING:
            return appointment_pending()
        if self is OrderLowLevelStatus.DRAW_COMPLETED:
            return draw_completed()
        if self is OrderLowLevelStatus.CANCELLED:
            return cancelled()
        if self is OrderLowLevelStatus.LOST:
            return lost()
        if self is OrderLowLevelStatus.DO_NOT_PROCESS:
            return do_not_process()
        if self is OrderLowLevelStatus.PARTIAL_RESULTS:
            return partial_results()
        if self is OrderLowLevelStatus.AWAITING_REGISTRATION:
            return awaiting_registration()
        if self is OrderLowLevelStatus.REGISTERED:
            return registered()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class HistoricalPullNonRetriableErrorDetails(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    NON_RETRIABLE_ERROR = "non_retriable_error"
    UNEXPECTED_ERROR = "unexpected_error"
    RETRY_QUOTA_EXHAUSTED = "retry_quota_exhausted"

    def visit(
        self,
        non_retriable_error: typing.Callable[[], T_Result],
        unexpected_error: typing.Callable[[], T_Result],
        retry_quota_exhausted: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is HistoricalPullNonRetriableErrorDetails.NON_RETRIABLE_ERROR:
            return non_retriable_error()
        if self is HistoricalPullNonRetriableErrorDetails.UNEXPECTED_ERROR:
            return unexpected_error()
        if self is HistoricalPullNonRetriableErrorDetails.RETRY_QUOTA_EXHAUSTED:
            return retry_quota_exhausted()



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.client_facing_provider_detailed import ClientFacingProviderDetailed
from .raw_client import AsyncRawProvidersClient, RawProvidersClient


class ProvidersClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawProvidersClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawProvidersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawProvidersClient
        """
        return self._raw_client

    def get_all(
        self, *, source_type: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[ClientFacingProviderDetailed]:
        """
        Get Provider list

        Parameters
        ----------
        source_type : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingProviderDetailed]
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.providers.get_all()
        """
        _response = self._raw_client.get_all(source_type=source_type, request_options=request_options)
        return _response.data


class AsyncProvidersClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawProvidersClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawProvidersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawProvidersClient
        """
        return self._raw_client

    async def get_all(
        self, *, source_type: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[ClientFacingProviderDetailed]:
        """
        Get Provider list

        Parameters
        ----------
        source_type : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingProviderDetailed]
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.providers.get_all()
        asyncio.run(main())
        """
        _response = await self._raw_client.get_all(source_type=source_type, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class LinkTokenExchangeResponse(UniversalBaseModel):
    link_token: str = pydantic.Field()
    """
    A short-lived Vital Link token for your Custom Link Widget to communicate with the Vital API.
    """

    link_web_url: str = pydantic.Field()
    """
    The web browser link to launch the default Vital Link experience. If you requested the token for one specific provider, the link would redirect directly to the provider authentication flow. Otherwise, the user would be presented with a list of providers based on your team and token configurations.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabTestsGetOrdersRequestOrderKey(str, enum.Enum):
    CREATED_AT = "created_at"
    PATIENT_NAME = "patient_name"
    LAST_STATUS = "last_status"

    def visit(
        self,
        created_at: typing.Callable[[], T_Result],
        patient_name: typing.Callable[[], T_Result],
        last_status: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LabTestsGetOrdersRequestOrderKey.CREATED_AT:
            return created_at()
        if self is LabTestsGetOrdersRequestOrderKey.PATIENT_NAME:
            return patient_name()
        if self is LabTestsGetOrdersRequestOrderKey.LAST_STATUS:
            return last_status()



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.client_sleep_cycle_response import ClientSleepCycleResponse
from .raw_client import AsyncRawSleepCycleClient, RawSleepCycleClient


class SleepCycleClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawSleepCycleClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawSleepCycleClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSleepCycleClient
        """
        return self._raw_client

    def get(
        self,
        user_id: str,
        *,
        start_date: str,
        end_date: typing.Optional[str] = None,
        provider: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClientSleepCycleResponse:
        """
        Get sleep cycle for user_id

        Parameters
        ----------
        user_id : str

        start_date : str

        end_date : typing.Optional[str]

        provider : typing.Optional[str]
            Provider oura/strava etc

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClientSleepCycleResponse
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.sleep_cycle.get(user_id='user_id', start_date='start_date', )
        """
        _response = self._raw_client.get(
            user_id, start_date=start_date, end_date=end_date, provider=provider, request_options=request_options
        )
        return _response.data


class AsyncSleepCycleClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawSleepCycleClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSleepCycleClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSleepCycleClient
        """
        return self._raw_client

    async def get(
        self,
        user_id: str,
        *,
        start_date: str,
        end_date: typing.Optional[str] = None,
        provider: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClientSleepCycleResponse:
        """
        Get sleep cycle for user_id

        Parameters
        ----------
        user_id : str

        start_date : str

        end_date : typing.Optional[str]

        provider : typing.Optional[str]
            Provider oura/strava etc

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClientSleepCycleResponse
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.sleep_cycle.get(user_id='user_id', start_date='start_date', )
        asyncio.run(main())
        """
        _response = await self._raw_client.get(
            user_id, start_date=start_date, end_date=end_date, provider=provider, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OrderActivationType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    CURRENT = "current"
    SCHEDULED = "scheduled"

    def visit(self, current: typing.Callable[[], T_Result], scheduled: typing.Callable[[], T_Result]) -> T_Result:
        if self is OrderActivationType.CURRENT:
            return current()
        if self is OrderActivationType.SCHEDULED:
            return scheduled()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class PeriodUnit(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    MINUTE = "minute"
    HOUR = "hour"
    DAY = "day"
    WEEK = "week"
    MONTH = "month"
    YEAR = "year"

    def visit(
        self,
        minute: typing.Callable[[], T_Result],
        hour: typing.Callable[[], T_Result],
        day: typing.Callable[[], T_Result],
        week: typing.Callable[[], T_Result],
        month: typing.Callable[[], T_Result],
        year: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is PeriodUnit.MINUTE:
            return minute()
        if self is PeriodUnit.HOUR:
            return hour()
        if self is PeriodUnit.DAY:
            return day()
        if self is PeriodUnit.WEEK:
            return week()
        if self is PeriodUnit.MONTH:
            return month()
        if self is PeriodUnit.YEAR:
            return year()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingWheelchairPushChangedEventType(str, enum.Enum):
    DAILY_DATA_WHEELCHAIR_PUSH_CREATED = "daily.data.wheelchair_push.created"
    DAILY_DATA_WHEELCHAIR_PUSH_UPDATED = "daily.data.wheelchair_push.updated"

    def visit(
        self,
        daily_data_wheelchair_push_created: typing.Callable[[], T_Result],
        daily_data_wheelchair_push_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingWheelchairPushChangedEventType.DAILY_DATA_WHEELCHAIR_PUSH_CREATED:
            return daily_data_wheelchair_push_created()
        if self is ClientFacingWheelchairPushChangedEventType.DAILY_DATA_WHEELCHAIR_PUSH_UPDATED:
            return daily_data_wheelchair_push_updated()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabTestSampleType(str, enum.Enum):
    """
    The type of sample used to perform a lab test. ℹ️ This enum is non-exhaustive.
    """

    DRIED_BLOOD_SPOT = "dried_blood_spot"
    ARM_COLLECTOR = "arm_collector"
    SERUM = "serum"
    SALIVA = "saliva"
    URINE = "urine"

    def visit(
        self,
        dried_blood_spot: typing.Callable[[], T_Result],
        arm_collector: typing.Callable[[], T_Result],
        serum: typing.Callable[[], T_Result],
        saliva: typing.Callable[[], T_Result],
        urine: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LabTestSampleType.DRIED_BLOOD_SPOT:
            return dried_blood_spot()
        if self is LabTestSampleType.ARM_COLLECTOR:
            return arm_collector()
        if self is LabTestSampleType.SERUM:
            return serum()
        if self is LabTestSampleType.SALIVA:
            return saliva()
        if self is LabTestSampleType.URINE:
            return urine()



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_facing_resource import ClientFacingResource
from .source_auth_type import SourceAuthType


class ClientFacingProviderDetailed(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    Name of source of information
    """

    slug: str = pydantic.Field()
    """
    Slug for designated source
    """

    description: str = pydantic.Field()
    """
    Description of source of information
    """

    logo: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL for source logo
    """

    auth_type: typing.Optional[SourceAuthType] = None
    supported_resources: typing.Optional[typing.List[ClientFacingResource]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Ethnicity(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    HISPANIC = "hispanic"
    NON_HISPANIC = "non_hispanic"
    ASHKENAZI_JEWISH = "ashkenazi_jewish"
    OTHER = "other"

    def visit(
        self,
        hispanic: typing.Callable[[], T_Result],
        non_hispanic: typing.Callable[[], T_Result],
        ashkenazi_jewish: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is Ethnicity.HISPANIC:
            return hispanic()
        if self is Ethnicity.NON_HISPANIC:
            return non_hispanic()
        if self is Ethnicity.ASHKENAZI_JEWISH:
            return ashkenazi_jewish()
        if self is Ethnicity.OTHER:
            return other()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabTestGenerationMethodFilter(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    AUTO = "auto"
    MANUAL = "manual"
    ALL = "all"

    def visit(
        self,
        auto: typing.Callable[[], T_Result],
        manual: typing.Callable[[], T_Result],
        all_: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is LabTestGenerationMethodFilter.AUTO:
            return auto()
        if self is LabTestGenerationMethodFilter.MANUAL:
            return manual()
        if self is LabTestGenerationMethodFilter.ALL:
            return all_()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Availability(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    AVAILABLE = "available"
    UNAVAILABLE = "unavailable"

    def visit(self, available: typing.Callable[[], T_Result], unavailable: typing.Callable[[], T_Result]) -> T_Result:
        if self is Availability.AVAILABLE:
            return available()
        if self is Availability.UNAVAILABLE:
            return unavailable()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class MarkerType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    BIOMARKER = "biomarker"
    PANEL = "panel"

    def visit(self, biomarker: typing.Callable[[], T_Result], panel: typing.Callable[[], T_Result]) -> T_Result:
        if self is MarkerType.BIOMARKER:
            return biomarker()
        if self is MarkerType.PANEL:
            return panel()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class TimeseriesResource(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    CALORIES_ACTIVE = "calories_active"
    CALORIES_BASAL = "calories_basal"
    DISTANCE = "distance"
    BLOOD_OXYGEN = "blood_oxygen"
    BLOOD_PRESSURE = "blood_pressure"
    BODY_FAT = "body_fat"
    BODY_WEIGHT = "body_weight"
    BODY_TEMPERATURE = "body_temperature"
    BODY_TEMPERATURE_DELTA = "body_temperature_delta"
    CHOLESTEROL = "cholesterol"
    CHOLESTEROL_LDL = "cholesterol/ldl"
    CHOLESTEROL_HDL = "cholesterol/hdl"
    CHOLESTEROL_TOTAL = "cholesterol/total"
    CHOLESTEROL_TRIGLYCERIDES = "cholesterol/triglycerides"
    ELECTROCARDIOGRAM_VOLTAGE = "electrocardiogram_voltage"
    FLOORS_CLIMBED = "floors_climbed"
    GLUCOSE = "glucose"
    HEARTRATE = "heartrate"
    HRV = "hrv"
    HYPNOGRAM = "hypnogram"
    IGE = "ige"
    IGG = "igg"
    RESPIRATORY_RATE = "respiratory_rate"
    STEPS = "steps"
    STRESS_LEVEL = "stress_level"
    VO_2_MAX = "vo2_max"
    WATER = "water"
    CAFFEINE = "caffeine"
    MINDFULNESS_MINUTES = "mindfulness_minutes"
    AFIB_BURDEN = "afib_burden"
    HEART_RATE_ALERT = "heart_rate_alert"
    STAND_HOUR = "stand_hour"
    STAND_DURATION = "stand_duration"
    SLEEP_APNEA_ALERT = "sleep_apnea_alert"
    SLEEP_BREATHING_DISTURBANCE = "sleep_breathing_disturbance"
    WHEELCHAIR_PUSH = "wheelchair_push"
    FORCED_EXPIRATORY_VOLUME_1 = "forced_expiratory_volume_1"
    FORCED_VITAL_CAPACITY = "forced_vital_capacity"
    PEAK_EXPIRATORY_FLOW_RATE = "peak_expiratory_flow_rate"
    INHALER_USAGE = "inhaler_usage"
    FALL = "fall"
    UV_EXPOSURE = "uv_exposure"
    DAYLIGHT_EXPOSURE = "daylight_exposure"
    HANDWASHING = "handwashing"
    BASAL_BODY_TEMPERATURE = "basal_body_temperature"
    BODY_MASS_INDEX = "body_mass_index"
    LEAN_BODY_MASS = "lean_body_mass"
    WAIST_CIRCUMFERENCE = "waist_circumference"
    HEART_RATE_RECOVERY_ONE_MINUTE = "heart_rate_recovery_one_minute"
    WORKOUT_DISTANCE = "workout_distance"
    WORKOUT_SWIMMING_STROKE = "workout_swimming_stroke"
    WORKOUT_DURATION = "workout_duration"
    INSULIN_INJECTION = "insulin_injection"
    CARBOHYDRATES = "carbohydrates"
    NOTE = "note"

    def visit(
        self,
        calories_active: typing.Callable[[], T_Result],
        calories_basal: typing.Callable[[], T_Result],
        distance: typing.Callable[[], T_Result],
        blood_oxygen: typing.Callable[[], T_Result],
        blood_pressure: typing.Callable[[], T_Result],
        body_fat: typing.Callable[[], T_Result],
        body_weight: typing.Callable[[], T_Result],
        body_temperature: typing.Callable[[], T_Result],
        body_temperature_delta: typing.Callable[[], T_Result],
        cholesterol: typing.Callable[[], T_Result],
        cholesterol_ldl: typing.Callable[[], T_Result],
        cholesterol_hdl: typing.Callable[[], T_Result],
        cholesterol_total: typing.Callable[[], T_Result],
        cholesterol_triglycerides: typing.Callable[[], T_Result],
        electrocardiogram_voltage: typing.Callable[[], T_Result],
        floors_climbed: typing.Callable[[], T_Result],
        glucose: typing.Callable[[], T_Result],
        heartrate: typing.Callable[[], T_Result],
        hrv: typing.Callable[[], T_Result],
        hypnogram: typing.Callable[[], T_Result],
        ige: typing.Callable[[], T_Result],
        igg: typing.Callable[[], T_Result],
        respiratory_rate: typing.Callable[[], T_Result],
        steps: typing.Callable[[], T_Result],
        stress_level: typing.Callable[[], T_Result],
        vo_2_max: typing.Callable[[], T_Result],
        water: typing.Callable[[], T_Result],
        caffeine: typing.Callable[[], T_Result],
        mindfulness_minutes: typing.Callable[[], T_Result],
        afib_burden: typing.Callable[[], T_Result],
        heart_rate_alert: typing.Callable[[], T_Result],
        stand_hour: typing.Callable[[], T_Result],
        stand_duration: typing.Callable[[], T_Result],
        sleep_apnea_alert: typing.Callable[[], T_Result],
        sleep_breathing_disturbance: typing.Callable[[], T_Result],
        wheelchair_push: typing.Callable[[], T_Result],
        forced_expiratory_volume_1: typing.Callable[[], T_Result],
        forced_vital_capacity: typing.Callable[[], T_Result],
        peak_expiratory_flow_rate: typing.Callable[[], T_Result],
        inhaler_usage: typing.Callable[[], T_Result],
        fall: typing.Callable[[], T_Result],
        uv_exposure: typing.Callable[[], T_Result],
        daylight_exposure: typing.Callable[[], T_Result],
        handwashing: typing.Callable[[], T_Result],
        basal_body_temperature: typing.Callable[[], T_Result],
        body_mass_index: typing.Callable[[], T_Result],
        lean_body_mass: typing.Callable[[], T_Result],
        waist_circumference: typing.Callable[[], T_Result],
        heart_rate_recovery_one_minute: typing.Callable[[], T_Result],
        workout_distance: typing.Callable[[], T_Result],
        workout_swimming_stroke: typing.Callable[[], T_Result],
        workout_duration: typing.Callable[[], T_Result],
        insulin_injection: typing.Callable[[], T_Result],
        carbohydrates: typing.Callable[[], T_Result],
        note: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is TimeseriesResource.CALORIES_ACTIVE:
            return calories_active()
        if self is TimeseriesResource.CALORIES_BASAL:
            return calories_basal()
        if self is TimeseriesResource.DISTANCE:
            return distance()
        if self is TimeseriesResource.BLOOD_OXYGEN:
            return blood_oxygen()
        if self is TimeseriesResource.BLOOD_PRESSURE:
            return blood_pressure()
        if self is TimeseriesResource.BODY_FAT:
            return body_fat()
        if self is TimeseriesResource.BODY_WEIGHT:
            return body_weight()
        if self is TimeseriesResource.BODY_TEMPERATURE:
            return body_temperature()
        if self is TimeseriesResource.BODY_TEMPERATURE_DELTA:
            return body_temperature_delta()
        if self is TimeseriesResource.CHOLESTEROL:
            return cholesterol()
        if self is TimeseriesResource.CHOLESTEROL_LDL:
            return cholesterol_ldl()
        if self is TimeseriesResource.CHOLESTEROL_HDL:
            return cholesterol_hdl()
        if self is TimeseriesResource.CHOLESTEROL_TOTAL:
            return cholesterol_total()
        if self is TimeseriesResource.CHOLESTEROL_TRIGLYCERIDES:
            return cholesterol_triglycerides()
        if self is TimeseriesResource.ELECTROCARDIOGRAM_VOLTAGE:
            return electrocardiogram_voltage()
        if self is TimeseriesResource.FLOORS_CLIMBED:
            return floors_climbed()
        if self is TimeseriesResource.GLUCOSE:
            return glucose()
        if self is TimeseriesResource.HEARTRATE:
            return heartrate()
        if self is TimeseriesResource.HRV:
            return hrv()
        if self is TimeseriesResource.HYPNOGRAM:
            return hypnogram()
        if self is TimeseriesResource.IGE:
            return ige()
        if self is TimeseriesResource.IGG:
            return igg()
        if self is TimeseriesResource.RESPIRATORY_RATE:
            return respiratory_rate()
        if self is TimeseriesResource.STEPS:
            return steps()
        if self is TimeseriesResource.STRESS_LEVEL:
            return stress_level()
        if self is TimeseriesResource.VO_2_MAX:
            return vo_2_max()
        if self is TimeseriesResource.WATER:
            return water()
        if self is TimeseriesResource.CAFFEINE:
            return caffeine()
        if self is TimeseriesResource.MINDFULNESS_MINUTES:
            return mindfulness_minutes()
        if self is TimeseriesResource.AFIB_BURDEN:
            return afib_burden()
        if self is TimeseriesResource.HEART_RATE_ALERT:
            return heart_rate_alert()
        if self is TimeseriesResource.STAND_HOUR:
            return stand_hour()
        if self is TimeseriesResource.STAND_DURATION:
            return stand_duration()
        if self is TimeseriesResource.SLEEP_APNEA_ALERT:
            return sleep_apnea_alert()
        if self is TimeseriesResource.SLEEP_BREATHING_DISTURBANCE:
            return sleep_breathing_disturbance()
        if self is TimeseriesResource.WHEELCHAIR_PUSH:
            return wheelchair_push()
        if self is TimeseriesResource.FORCED_EXPIRATORY_VOLUME_1:
            return forced_expiratory_volume_1()
        if self is TimeseriesResource.FORCED_VITAL_CAPACITY:
            return forced_vital_capacity()
        if self is TimeseriesResource.PEAK_EXPIRATORY_FLOW_RATE:
            return peak_expiratory_flow_rate()
        if self is TimeseriesResource.INHALER_USAGE:
            return inhaler_usage()
        if self is TimeseriesResource.FALL:
            return fall()
        if self is TimeseriesResource.UV_EXPOSURE:
            return uv_exposure()
        if self is TimeseriesResource.DAYLIGHT_EXPOSURE:
            return daylight_exposure()
        if self is TimeseriesResource.HANDWASHING:
            return handwashing()
        if self is TimeseriesResource.BASAL_BODY_TEMPERATURE:
            return basal_body_temperature()
        if self is TimeseriesResource.BODY_MASS_INDEX:
            return body_mass_index()
        if self is TimeseriesResource.LEAN_BODY_MASS:
            return lean_body_mass()
        if self is TimeseriesResource.WAIST_CIRCUMFERENCE:
            return waist_circumference()
        if self is TimeseriesResource.HEART_RATE_RECOVERY_ONE_MINUTE:
            return heart_rate_recovery_one_minute()
        if self is TimeseriesResource.WORKOUT_DISTANCE:
            return workout_distance()
        if self is TimeseriesResource.WORKOUT_SWIMMING_STROKE:
            return workout_swimming_stroke()
        if self is TimeseriesResource.WORKOUT_DURATION:
            return workout_duration()
        if self is TimeseriesResource.INSULIN_INJECTION:
            return insulin_injection()
        if self is TimeseriesResource.CARBOHYDRATES:
            return carbohydrates()
        if self is TimeseriesResource.NOTE:
            return note()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingAppointmentChangedEventType(str, enum.Enum):
    LABTEST_APPOINTMENT_CREATED = "labtest.appointment.created"
    LABTEST_APPOINTMENT_UPDATED = "labtest.appointment.updated"

    def visit(
        self,
        labtest_appointment_created: typing.Callable[[], T_Result],
        labtest_appointment_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingAppointmentChangedEventType.LABTEST_APPOINTMENT_CREATED:
            return labtest_appointment_created()
        if self is ClientFacingAppointmentChangedEventType.LABTEST_APPOINTMENT_UPDATED:
            return labtest_appointment_updated()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingHeartRateRecoveryOneMinuteChangedEventType(str, enum.Enum):
    DAILY_DATA_HEART_RATE_RECOVERY_ONE_MINUTE_CREATED = "daily.data.heart_rate_recovery_one_minute.created"
    DAILY_DATA_HEART_RATE_RECOVERY_ONE_MINUTE_UPDATED = "daily.data.heart_rate_recovery_one_minute.updated"

    def visit(
        self,
        daily_data_heart_rate_recovery_one_minute_created: typing.Callable[[], T_Result],
        daily_data_heart_rate_recovery_one_minute_updated: typing.Callable[[], T_Result],
    ) -> T_Result:
        if (
            self
            is ClientFacingHeartRateRecoveryOneMinuteChangedEventType.DAILY_DATA_HEART_RATE_RECOVERY_ONE_MINUTE_CREATED
        ):
            return daily_data_heart_rate_recovery_one_minute_created()
        if (
            self
            is ClientFacingHeartRateRecoveryOneMinuteChangedEventType.DAILY_DATA_HEART_RATE_RECOVERY_ONE_MINUTE_UPDATED
        ):
            return daily_data_heart_rate_recovery_one_minute_updated()



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class UserRefreshSuccessResponse(UniversalBaseModel):
    success: bool = pydantic.Field()
    """
    Whether operation was successful or not
    """

    user_id: str = pydantic.Field()
    """
    A unique ID representing the end user. Typically this will be a user ID from your application. Personally identifiable information, such as an email address or phone number, should not be used in the client_user_id.
    """

    refreshed_sources: typing.List[str]
    in_progress_sources: typing.List[str]
    failed_sources: typing.List[str]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.client_facing_physician import ClientFacingPhysician
from ..types.client_facing_team import ClientFacingTeam
from ..types.client_facing_user import ClientFacingUser
from .raw_client import AsyncRawTeamClient, RawTeamClient


class TeamClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTeamClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTeamClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTeamClient
        """
        return self._raw_client

    def get_link_config(
        self, *, vital_link_token: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Dict[str, typing.Optional[typing.Any]]:
        """
        Post teams.

        Parameters
        ----------
        vital_link_token : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Optional[typing.Any]]
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.team.get_link_config()
        """
        _response = self._raw_client.get_link_config(vital_link_token=vital_link_token, request_options=request_options)
        return _response.data

    def get(self, team_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> ClientFacingTeam:
        """
        Get team.

        Parameters
        ----------
        team_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClientFacingTeam
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.team.get(team_id='team_id', )
        """
        _response = self._raw_client.get(team_id, request_options=request_options)
        return _response.data

    def get_user_by_id(
        self, *, query_id: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[ClientFacingUser]:
        """
        Search team users by user_id

        Parameters
        ----------
        query_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingUser]
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.team.get_user_by_id()
        """
        _response = self._raw_client.get_user_by_id(query_id=query_id, request_options=request_options)
        return _response.data

    def get_svix_url(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Dict[str, typing.Optional[typing.Any]]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Optional[typing.Any]]
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.team.get_svix_url()
        """
        _response = self._raw_client.get_svix_url(request_options=request_options)
        return _response.data

    def get_source_priorities(
        self, *, data_type: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[typing.Dict[str, typing.Optional[typing.Any]]]:
        """
        GET source priorities.

        Parameters
        ----------
        data_type : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[typing.Dict[str, typing.Optional[typing.Any]]]
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.team.get_source_priorities()
        """
        _response = self._raw_client.get_source_priorities(data_type=data_type, request_options=request_options)
        return _response.data

    def update_source_priorities(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[typing.Dict[str, typing.Optional[typing.Any]]]:
        """
        Patch source priorities.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[typing.Dict[str, typing.Optional[typing.Any]]]
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.team.update_source_priorities()
        """
        _response = self._raw_client.update_source_priorities(request_options=request_options)
        return _response.data

    def get_physicians(
        self, team_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[ClientFacingPhysician]:
        """
        Parameters
        ----------
        team_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingPhysician]
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.team.get_physicians(team_id='team_id', )
        """
        _response = self._raw_client.get_physicians(team_id, request_options=request_options)
        return _response.data


class AsyncTeamClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTeamClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTeamClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTeamClient
        """
        return self._raw_client

    async def get_link_config(
        self, *, vital_link_token: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Dict[str, typing.Optional[typing.Any]]:
        """
        Post teams.

        Parameters
        ----------
        vital_link_token : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Optional[typing.Any]]
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.team.get_link_config()
        asyncio.run(main())
        """
        _response = await self._raw_client.get_link_config(
            vital_link_token=vital_link_token, request_options=request_options
        )
        return _response.data

    async def get(self, team_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> ClientFacingTeam:
        """
        Get team.

        Parameters
        ----------
        team_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClientFacingTeam
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.team.get(team_id='team_id', )
        asyncio.run(main())
        """
        _response = await self._raw_client.get(team_id, request_options=request_options)
        return _response.data

    async def get_user_by_id(
        self, *, query_id: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[ClientFacingUser]:
        """
        Search team users by user_id

        Parameters
        ----------
        query_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingUser]
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.team.get_user_by_id()
        asyncio.run(main())
        """
        _response = await self._raw_client.get_user_by_id(query_id=query_id, request_options=request_options)
        return _response.data

    async def get_svix_url(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Dict[str, typing.Optional[typing.Any]]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Optional[typing.Any]]
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.team.get_svix_url()
        asyncio.run(main())
        """
        _response = await self._raw_client.get_svix_url(request_options=request_options)
        return _response.data

    async def get_source_priorities(
        self, *, data_type: typing.Optional[str] = None, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[typing.Dict[str, typing.Optional[typing.Any]]]:
        """
        GET source priorities.

        Parameters
        ----------
        data_type : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[typing.Dict[str, typing.Optional[typing.Any]]]
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.team.get_source_priorities()
        asyncio.run(main())
        """
        _response = await self._raw_client.get_source_priorities(data_type=data_type, request_options=request_options)
        return _response.data

    async def update_source_priorities(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[typing.Dict[str, typing.Optional[typing.Any]]]:
        """
        Patch source priorities.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[typing.Dict[str, typing.Optional[typing.Any]]]
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.team.update_source_priorities()
        asyncio.run(main())
        """
        _response = await self._raw_client.update_source_priorities(request_options=request_options)
        return _response.data

    async def get_physicians(
        self, team_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[ClientFacingPhysician]:
        """
        Parameters
        ----------
        team_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[ClientFacingPhysician]
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.team.get_physicians(team_id='team_id', )
        asyncio.run(main())
        """
        _response = await self._raw_client.get_physicians(team_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from .historical_pull_non_retriable_error_details import HistoricalPullNonRetriableErrorDetails
from .historical_pull_retriable_error_details import HistoricalPullRetriableErrorDetails

SingleHistoricalPullStatisticsErrorDetails = typing.Union[
    HistoricalPullRetriableErrorDetails, HistoricalPullNonRetriableErrorDetails
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OvulationTestEntryTestResult(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    NEGATIVE = "negative"
    POSITIVE = "positive"
    LUTEINIZING_HORMONE_SURGE = "luteinizing_hormone_surge"
    ESTROGEN_SURGE = "estrogen_surge"
    INDETERMINATE = "indeterminate"

    def visit(
        self,
        negative: typing.Callable[[], T_Result],
        positive: typing.Callable[[], T_Result],
        luteinizing_hormone_surge: typing.Callable[[], T_Result],
        estrogen_surge: typing.Callable[[], T_Result],
        indeterminate: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is OvulationTestEntryTestResult.NEGATIVE:
            return negative()
        if self is OvulationTestEntryTestResult.POSITIVE:
            return positive()
        if self is OvulationTestEntryTestResult.LUTEINIZING_HORMONE_SURGE:
            return luteinizing_hormone_surge()
        if self is OvulationTestEntryTestResult.ESTROGEN_SURGE:
            return estrogen_surge()
        if self is OvulationTestEntryTestResult.INDETERMINATE:
            return indeterminate()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class GenderIdentity(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    MALE = "male"
    FEMALE = "female"
    FEMALE_TO_MALE_FTM_TRANSGENDER_MALE_TRANS_MAN = "female_to_male_ftm_transgender_male_trans_man"
    MALE_TO_FEMALE_MTF_TRANSGENDER_FEMALE_TRANS_WOMAN = "male_to_female_mtf_transgender_female_trans_woman"
    GENDERQUEER = "genderqueer"
    OTHER = "other"

    def visit(
        self,
        male: typing.Callable[[], T_Result],
        female: typing.Callable[[], T_Result],
        female_to_male_ftm_transgender_male_trans_man: typing.Callable[[], T_Result],
        male_to_female_mtf_transgender_female_trans_woman: typing.Callable[[], T_Result],
        genderqueer: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is GenderIdentity.MALE:
            return male()
        if self is GenderIdentity.FEMALE:
            return female()
        if self is GenderIdentity.FEMALE_TO_MALE_FTM_TRANSGENDER_MALE_TRANS_MAN:
            return female_to_male_ftm_transgender_male_trans_man()
        if self is GenderIdentity.MALE_TO_FEMALE_MTF_TRANSGENDER_FEMALE_TRANS_WOMAN:
            return male_to_female_mtf_transgender_female_trans_woman()
        if self is GenderIdentity.GENDERQUEER:
            return genderqueer()
        if self is GenderIdentity.OTHER:
            return other()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class PayorCodeExternalProvider(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    CHANGE_HEALTHCARE = "change_healthcare"
    AVAILITY = "availity"
    STEDI = "stedi"

    def visit(
        self,
        change_healthcare: typing.Callable[[], T_Result],
        availity: typing.Callable[[], T_Result],
        stedi: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is PayorCodeExternalProvider.CHANGE_HEALTHCARE:
            return change_healthcare()
        if self is PayorCodeExternalProvider.AVAILITY:
            return availity()
        if self is PayorCodeExternalProvider.STEDI:
            return stedi()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ProviderConnectionErrorErrorType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    TOKEN_REFRESH_FAILED = "token_refresh_failed"
    WEBHOOK_REGISTRATION_FAILED = "webhook_registration_failed"
    USER_NOT_FOUND = "user_not_found"
    DEREGISTERED_PER_PROVIDER = "deregistered_per_provider"
    REQUIRED_SCOPES_NOT_GRANTED = "required_scopes_not_granted"
    PROVIDER_CREDENTIAL_ERROR = "provider_credential_error"
    UNKNOWN = "unknown"

    def visit(
        self,
        token_refresh_failed: typing.Callable[[], T_Result],
        webhook_registration_failed: typing.Callable[[], T_Result],
        user_not_found: typing.Callable[[], T_Result],
        deregistered_per_provider: typing.Callable[[], T_Result],
        required_scopes_not_granted: typing.Callable[[], T_Result],
        provider_credential_error: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ProviderConnectionErrorErrorType.TOKEN_REFRESH_FAILED:
            return token_refresh_failed()
        if self is ProviderConnectionErrorErrorType.WEBHOOK_REGISTRATION_FAILED:
            return webhook_registration_failed()
        if self is ProviderConnectionErrorErrorType.USER_NOT_FOUND:
            return user_not_found()
        if self is ProviderConnectionErrorErrorType.DEREGISTERED_PER_PROVIDER:
            return deregistered_per_provider()
        if self is ProviderConnectionErrorErrorType.REQUIRED_SCOPES_NOT_GRANTED:
            return required_scopes_not_granted()
        if self is ProviderConnectionErrorErrorType.PROVIDER_CREDENTIAL_ERROR:
            return provider_credential_error()
        if self is ProviderConnectionErrorErrorType.UNKNOWN:
            return unknown()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ContinuousQueryTaskStatus(str, enum.Enum):
    """
    This has to match the `continuous_query_task_status` enum type in postgres. ℹ️ This enum is non-exhaustive.
    """

    SCHEDULED = "scheduled"
    STARTED = "started"
    COMPLETED = "completed"
    ERROR = "error"

    def visit(
        self,
        scheduled: typing.Callable[[], T_Result],
        started: typing.Callable[[], T_Result],
        completed: typing.Callable[[], T_Result],
        error: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ContinuousQueryTaskStatus.SCHEDULED:
            return scheduled()
        if self is ContinuousQueryTaskStatus.STARTED:
            return started()
        if self is ContinuousQueryTaskStatus.COMPLETED:
            return completed()
        if self is ContinuousQueryTaskStatus.ERROR:
            return error()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class HomePregnancyTestEntryTestResult(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    NEGATIVE = "negative"
    POSITIVE = "positive"
    INDETERMINATE = "indeterminate"

    def visit(
        self,
        negative: typing.Callable[[], T_Result],
        positive: typing.Callable[[], T_Result],
        indeterminate: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is HomePregnancyTestEntryTestResult.NEGATIVE:
            return negative()
        if self is HomePregnancyTestEntryTestResult.POSITIVE:
            return positive()
        if self is HomePregnancyTestEntryTestResult.INDETERMINATE:
            return indeterminate()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .appointment_event_status import AppointmentEventStatus
from .appointment_provider import AppointmentProvider
from .appointment_status import AppointmentStatus
from .appointment_type import AppointmentType
from .client_facing_appointment_event import ClientFacingAppointmentEvent
from .lng_lat import LngLat
from .us_address import UsAddress


class ClientFacingAppointment(UniversalBaseModel):
    id: str
    user_id: str
    order_id: str
    address: UsAddress
    location: LngLat
    start_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Time is in UTC
    """

    end_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Time is in UTC
    """

    iana_timezone: typing.Optional[str] = None
    type: AppointmentType
    provider: AppointmentProvider
    status: AppointmentStatus
    provider_id: str
    can_reschedule: bool
    event_status: AppointmentEventStatus
    event_data: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    events: typing.List[ClientFacingAppointmentEvent]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .ethnicity import Ethnicity
from .gender import Gender
from .gender_identity import GenderIdentity
from .guarantor_details import GuarantorDetails
from .race import Race
from .sexual_orientation import SexualOrientation


class PatientDetailsWithValidation(UniversalBaseModel):
    """
    Patient details with validation for first_name, last_name, email, and dob.
    """

    first_name: str
    last_name: str
    dob: str
    gender: Gender
    phone_number: str
    email: str
    medical_proxy: typing.Optional[GuarantorDetails] = pydantic.Field(default=None)
    """
    Parent/medical_proxy details. Required if patient is a minor.
    """

    race: typing.Optional[Race] = pydantic.Field(default=None)
    """
    If not provided, will be set to 'Not Specified'
    """

    ethnicity: typing.Optional[Ethnicity] = pydantic.Field(default=None)
    """
    If not provided, will be set to 'Not Specified'
    """

    sexual_orientation: typing.Optional[SexualOrientation] = pydantic.Field(default=None)
    """
    If not provided, will be set to 'Not Specified'
    """

    gender_identity: typing.Optional[GenderIdentity] = pydantic.Field(default=None)
    """
    If not provided, will be set to 'Not Specified'
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingElectrocardiogramInconclusiveCause(str, enum.Enum):
    HIGH_HEART_RATE = "high_heart_rate"
    LOW_HEART_RATE = "low_heart_rate"
    POOR_READING = "poor_reading"

    def visit(
        self,
        high_heart_rate: typing.Callable[[], T_Result],
        low_heart_rate: typing.Callable[[], T_Result],
        poor_reading: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingElectrocardiogramInconclusiveCause.HIGH_HEART_RATE:
            return high_heart_rate()
        if self is ClientFacingElectrocardiogramInconclusiveCause.LOW_HEART_RATE:
            return low_heart_rate()
        if self is ClientFacingElectrocardiogramInconclusiveCause.POOR_READING:
            return poor_reading()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.resend_webhook_response import ResendWebhookResponse
from .raw_client import AsyncRawOrderClient, RawOrderClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class OrderClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawOrderClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawOrderClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawOrderClient
        """
        return self._raw_client

    def resend_events(
        self,
        *,
        order_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        start_at: typing.Optional[dt.datetime] = OMIT,
        end_at: typing.Optional[dt.datetime] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResendWebhookResponse:
        """
        Replay a webhook for a given set of orders

        Parameters
        ----------
        order_ids : typing.Optional[typing.Sequence[str]]

        start_at : typing.Optional[dt.datetime]

        end_at : typing.Optional[dt.datetime]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResendWebhookResponse
            Successful Response

        Examples
        --------
        from vital import Vital
        client = Vital(api_key="YOUR_API_KEY", )
        client.order.resend_events()
        """
        _response = self._raw_client.resend_events(
            order_ids=order_ids, start_at=start_at, end_at=end_at, request_options=request_options
        )
        return _response.data


class AsyncOrderClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawOrderClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawOrderClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawOrderClient
        """
        return self._raw_client

    async def resend_events(
        self,
        *,
        order_ids: typing.Optional[typing.Sequence[str]] = OMIT,
        start_at: typing.Optional[dt.datetime] = OMIT,
        end_at: typing.Optional[dt.datetime] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResendWebhookResponse:
        """
        Replay a webhook for a given set of orders

        Parameters
        ----------
        order_ids : typing.Optional[typing.Sequence[str]]

        start_at : typing.Optional[dt.datetime]

        end_at : typing.Optional[dt.datetime]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResendWebhookResponse
            Successful Response

        Examples
        --------
        from vital import AsyncVital
        import asyncio
        client = AsyncVital(api_key="YOUR_API_KEY", )
        async def main() -> None:
            await client.order.resend_events()
        asyncio.run(main())
        """
        _response = await self._raw_client.resend_events(
            order_ids=order_ids, start_at=start_at, end_at=end_at, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_facing_at_home_phlebotomy_order import ClientFacingAtHomePhlebotomyOrder
from .client_facing_testkit_order import ClientFacingTestkitOrder
from .client_facing_walk_in_test_order import ClientFacingWalkInTestOrder


class ClientFacingOrderDetails_WalkInTest(UniversalBaseModel):
    type: typing.Literal["walk_in_test"] = "walk_in_test"
    data: typing.Optional[ClientFacingWalkInTestOrder] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class ClientFacingOrderDetails_Testkit(UniversalBaseModel):
    type: typing.Literal["testkit"] = "testkit"
    data: typing.Optional[ClientFacingTestkitOrder] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class ClientFacingOrderDetails_AtHomePhlebotomy(UniversalBaseModel):
    type: typing.Literal["at_home_phlebotomy"] = "at_home_phlebotomy"
    data: typing.Optional[ClientFacingAtHomePhlebotomyOrder] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


ClientFacingOrderDetails = typing.Union[
    ClientFacingOrderDetails_WalkInTest, ClientFacingOrderDetails_Testkit, ClientFacingOrderDetails_AtHomePhlebotomy
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ResponsibleRelationship(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    SELF = "Self"
    SPOUSE = "Spouse"
    OTHER = "Other"

    def visit(
        self,
        self_: typing.Callable[[], T_Result],
        spouse: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ResponsibleRelationship.SELF:
            return self_()
        if self is ResponsibleRelationship.SPOUSE:
            return spouse()
        if self is ResponsibleRelationship.OTHER:
            return other()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Select(str, enum.Enum):
    SELECT_ALL = "*"

    def visit(self, select_all: typing.Callable[[], T_Result]) -> T_Result:
        if self is Select.SELECT_ALL:
            return select_all()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OrderStatus(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    RECEIVED_WALK_IN_TEST_ORDERED = "received.walk_in_test.ordered"
    RECEIVED_WALK_IN_TEST_REQUISITION_CREATED = "received.walk_in_test.requisition_created"
    RECEIVED_WALK_IN_TEST_REQUISITION_BYPASSED = "received.walk_in_test.requisition_bypassed"
    COMPLETED_WALK_IN_TEST_COMPLETED = "completed.walk_in_test.completed"
    SAMPLE_WITH_LAB_WALK_IN_TEST_PARTIAL_RESULTS = "sample_with_lab.walk_in_test.partial_results"
    FAILED_WALK_IN_TEST_SAMPLE_ERROR = "failed.walk_in_test.sample_error"
    CANCELLED_WALK_IN_TEST_CANCELLED = "cancelled.walk_in_test.cancelled"
    COLLECTING_SAMPLE_WALK_IN_TEST_APPOINTMENT_PENDING = "collecting_sample.walk_in_test.appointment_pending"
    COLLECTING_SAMPLE_WALK_IN_TEST_APPOINTMENT_SCHEDULED = "collecting_sample.walk_in_test.appointment_scheduled"
    COLLECTING_SAMPLE_WALK_IN_TEST_APPOINTMENT_CANCELLED = "collecting_sample.walk_in_test.appointment_cancelled"
    RECEIVED_AT_HOME_PHLEBOTOMY_ORDERED = "received.at_home_phlebotomy.ordered"
    RECEIVED_AT_HOME_PHLEBOTOMY_REQUISITION_CREATED = "received.at_home_phlebotomy.requisition_created"
    RECEIVED_AT_HOME_PHLEBOTOMY_REQUISITION_BYPASSED = "received.at_home_phlebotomy.requisition_bypassed"
    COLLECTING_SAMPLE_AT_HOME_PHLEBOTOMY_APPOINTMENT_PENDING = (
        "collecting_sample.at_home_phlebotomy.appointment_pending"
    )
    COLLECTING_SAMPLE_AT_HOME_PHLEBOTOMY_APPOINTMENT_SCHEDULED = (
        "collecting_sample.at_home_phlebotomy.appointment_scheduled"
    )
    COLLECTING_SAMPLE_AT_HOME_PHLEBOTOMY_DRAW_COMPLETED = "collecting_sample.at_home_phlebotomy.draw_completed"
    COLLECTING_SAMPLE_AT_HOME_PHLEBOTOMY_APPOINTMENT_CANCELLED = (
        "collecting_sample.at_home_phlebotomy.appointment_cancelled"
    )
    COMPLETED_AT_HOME_PHLEBOTOMY_COMPLETED = "completed.at_home_phlebotomy.completed"
    SAMPLE_WITH_LAB_AT_HOME_PHLEBOTOMY_PARTIAL_RESULTS = "sample_with_lab.at_home_phlebotomy.partial_results"
    CANCELLED_AT_HOME_PHLEBOTOMY_CANCELLED = "cancelled.at_home_phlebotomy.cancelled"
    FAILED_AT_HOME_PHLEBOTOMY_SAMPLE_ERROR = "failed.at_home_phlebotomy.sample_error"
    RECEIVED_TESTKIT_ORDERED = "received.testkit.ordered"
    RECEIVED_TESTKIT_AWAITING_REGISTRATION = "received.testkit.awaiting_registration"
    RECEIVED_TESTKIT_REQUISITION_CREATED = "received.testkit.requisition_created"
    RECEIVED_TESTKIT_REQUISITION_BYPASSED = "received.testkit.requisition_bypassed"
    RECEIVED_TESTKIT_REGISTERED = "received.testkit.registered"
    COLLECTING_SAMPLE_TESTKIT_TRANSIT_CUSTOMER = "collecting_sample.testkit.transit_customer"
    COLLECTING_SAMPLE_TESTKIT_OUT_FOR_DELIVERY = "collecting_sample.testkit.out_for_delivery"
    COLLECTING_SAMPLE_TESTKIT_WITH_CUSTOMER = "collecting_sample.testkit.with_customer"
    COLLECTING_SAMPLE_TESTKIT_TRANSIT_LAB = "collecting_sample.testkit.transit_lab"
    SAMPLE_WITH_LAB_TESTKIT_DELIVERED_TO_LAB = "sample_with_lab.testkit.delivered_to_lab"
    COMPLETED_TESTKIT_COMPLETED = "completed.testkit.completed"
    FAILED_TESTKIT_FAILURE_TO_DELIVER_TO_CUSTOMER = "failed.testkit.failure_to_deliver_to_customer"
    FAILED_TESTKIT_FAILURE_TO_DELIVER_TO_LAB = "failed.testkit.failure_to_deliver_to_lab"
    FAILED_TESTKIT_SAMPLE_ERROR = "failed.testkit.sample_error"
    FAILED_TESTKIT_LOST = "failed.testkit.lost"
    CANCELLED_TESTKIT_CANCELLED = "cancelled.testkit.cancelled"
    CANCELLED_TESTKIT_DO_NOT_PROCESS = "cancelled.testkit.do_not_process"
    COLLECTING_SAMPLE_TESTKIT_PROBLEM_IN_TRANSIT_CUSTOMER = "collecting_sample.testkit.problem_in_transit_customer"
    COLLECTING_SAMPLE_TESTKIT_PROBLEM_IN_TRANSIT_LAB = "collecting_sample.testkit.problem_in_transit_lab"

    def visit(
        self,
        received_walk_in_test_ordered: typing.Callable[[], T_Result],
        received_walk_in_test_requisition_created: typing.Callable[[], T_Result],
        received_walk_in_test_requisition_bypassed: typing.Callable[[], T_Result],
        completed_walk_in_test_completed: typing.Callable[[], T_Result],
        sample_with_lab_walk_in_test_partial_results: typing.Callable[[], T_Result],
        failed_walk_in_test_sample_error: typing.Callable[[], T_Result],
        cancelled_walk_in_test_cancelled: typing.Callable[[], T_Result],
        collecting_sample_walk_in_test_appointment_pending: typing.Callable[[], T_Result],
        collecting_sample_walk_in_test_appointment_scheduled: typing.Callable[[], T_Result],
        collecting_sample_walk_in_test_appointment_cancelled: typing.Callable[[], T_Result],
        received_at_home_phlebotomy_ordered: typing.Callable[[], T_Result],
        received_at_home_phlebotomy_requisition_created: typing.Callable[[], T_Result],
        received_at_home_phlebotomy_requisition_bypassed: typing.Callable[[], T_Result],
        collecting_sample_at_home_phlebotomy_appointment_pending: typing.Callable[[], T_Result],
        collecting_sample_at_home_phlebotomy_appointment_scheduled: typing.Callable[[], T_Result],
        collecting_sample_at_home_phlebotomy_draw_completed: typing.Callable[[], T_Result],
        collecting_sample_at_home_phlebotomy_appointment_cancelled: typing.Callable[[], T_Result],
        completed_at_home_phlebotomy_completed: typing.Callable[[], T_Result],
        sample_with_lab_at_home_phlebotomy_partial_results: typing.Callable[[], T_Result],
        cancelled_at_home_phlebotomy_cancelled: typing.Callable[[], T_Result],
        failed_at_home_phlebotomy_sample_error: typing.Callable[[], T_Result],
        received_testkit_ordered: typing.Callable[[], T_Result],
        received_testkit_awaiting_registration: typing.Callable[[], T_Result],
        received_testkit_requisition_created: typing.Callable[[], T_Result],
        received_testkit_requisition_bypassed: typing.Callable[[], T_Result],
        received_testkit_registered: typing.Callable[[], T_Result],
        collecting_sample_testkit_transit_customer: typing.Callable[[], T_Result],
        collecting_sample_testkit_out_for_delivery: typing.Callable[[], T_Result],
        collecting_sample_testkit_with_customer: typing.Callable[[], T_Result],
        collecting_sample_testkit_transit_lab: typing.Callable[[], T_Result],
        sample_with_lab_testkit_delivered_to_lab: typing.Callable[[], T_Result],
        completed_testkit_completed: typing.Callable[[], T_Result],
        failed_testkit_failure_to_deliver_to_customer: typing.Callable[[], T_Result],
        failed_testkit_failure_to_deliver_to_lab: typing.Callable[[], T_Result],
        failed_testkit_sample_error: typing.Callable[[], T_Result],
        failed_testkit_lost: typing.Callable[[], T_Result],
        cancelled_testkit_cancelled: typing.Callable[[], T_Result],
        cancelled_testkit_do_not_process: typing.Callable[[], T_Result],
        collecting_sample_testkit_problem_in_transit_customer: typing.Callable[[], T_Result],
        collecting_sample_testkit_problem_in_transit_lab: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is OrderStatus.RECEIVED_WALK_IN_TEST_ORDERED:
            return received_walk_in_test_ordered()
        if self is OrderStatus.RECEIVED_WALK_IN_TEST_REQUISITION_CREATED:
            return received_walk_in_test_requisition_created()
        if self is OrderStatus.RECEIVED_WALK_IN_TEST_REQUISITION_BYPASSED:
            return received_walk_in_test_requisition_bypassed()
        if self is OrderStatus.COMPLETED_WALK_IN_TEST_COMPLETED:
            return completed_walk_in_test_completed()
        if self is OrderStatus.SAMPLE_WITH_LAB_WALK_IN_TEST_PARTIAL_RESULTS:
            return sample_with_lab_walk_in_test_partial_results()
        if self is OrderStatus.FAILED_WALK_IN_TEST_SAMPLE_ERROR:
            return failed_walk_in_test_sample_error()
        if self is OrderStatus.CANCELLED_WALK_IN_TEST_CANCELLED:
            return cancelled_walk_in_test_cancelled()
        if self is OrderStatus.COLLECTING_SAMPLE_WALK_IN_TEST_APPOINTMENT_PENDING:
            return collecting_sample_walk_in_test_appointment_pending()
        if self is OrderStatus.COLLECTING_SAMPLE_WALK_IN_TEST_APPOINTMENT_SCHEDULED:
            return collecting_sample_walk_in_test_appointment_scheduled()
        if self is OrderStatus.COLLECTING_SAMPLE_WALK_IN_TEST_APPOINTMENT_CANCELLED:
            return collecting_sample_walk_in_test_appointment_cancelled()
        if self is OrderStatus.RECEIVED_AT_HOME_PHLEBOTOMY_ORDERED:
            return received_at_home_phlebotomy_ordered()
        if self is OrderStatus.RECEIVED_AT_HOME_PHLEBOTOMY_REQUISITION_CREATED:
            return received_at_home_phlebotomy_requisition_created()
        if self is OrderStatus.RECEIVED_AT_HOME_PHLEBOTOMY_REQUISITION_BYPASSED:
            return received_at_home_phlebotomy_requisition_bypassed()
        if self is OrderStatus.COLLECTING_SAMPLE_AT_HOME_PHLEBOTOMY_APPOINTMENT_PENDING:
            return collecting_sample_at_home_phlebotomy_appointment_pending()
        if self is OrderStatus.COLLECTING_SAMPLE_AT_HOME_PHLEBOTOMY_APPOINTMENT_SCHEDULED:
            return collecting_sample_at_home_phlebotomy_appointment_scheduled()
        if self is OrderStatus.COLLECTING_SAMPLE_AT_HOME_PHLEBOTOMY_DRAW_COMPLETED:
            return collecting_sample_at_home_phlebotomy_draw_completed()
        if self is OrderStatus.COLLECTING_SAMPLE_AT_HOME_PHLEBOTOMY_APPOINTMENT_CANCELLED:
            return collecting_sample_at_home_phlebotomy_appointment_cancelled()
        if self is OrderStatus.COMPLETED_AT_HOME_PHLEBOTOMY_COMPLETED:
            return completed_at_home_phlebotomy_completed()
        if self is OrderStatus.SAMPLE_WITH_LAB_AT_HOME_PHLEBOTOMY_PARTIAL_RESULTS:
            return sample_with_lab_at_home_phlebotomy_partial_results()
        if self is OrderStatus.CANCELLED_AT_HOME_PHLEBOTOMY_CANCELLED:
            return cancelled_at_home_phlebotomy_cancelled()
        if self is OrderStatus.FAILED_AT_HOME_PHLEBOTOMY_SAMPLE_ERROR:
            return failed_at_home_phlebotomy_sample_error()
        if self is OrderStatus.RECEIVED_TESTKIT_ORDERED:
            return received_testkit_ordered()
        if self is OrderStatus.RECEIVED_TESTKIT_AWAITING_REGISTRATION:
            return received_testkit_awaiting_registration()
        if self is OrderStatus.RECEIVED_TESTKIT_REQUISITION_CREATED:
            return received_testkit_requisition_created()
        if self is OrderStatus.RECEIVED_TESTKIT_REQUISITION_BYPASSED:
            return received_testkit_requisition_bypassed()
        if self is OrderStatus.RECEIVED_TESTKIT_REGISTERED:
            return received_testkit_registered()
        if self is OrderStatus.COLLECTING_SAMPLE_TESTKIT_TRANSIT_CUSTOMER:
            return collecting_sample_testkit_transit_customer()
        if self is OrderStatus.COLLECTING_SAMPLE_TESTKIT_OUT_FOR_DELIVERY:
            return collecting_sample_testkit_out_for_delivery()
        if self is OrderStatus.COLLECTING_SAMPLE_TESTKIT_WITH_CUSTOMER:
            return collecting_sample_testkit_with_customer()
        if self is OrderStatus.COLLECTING_SAMPLE_TESTKIT_TRANSIT_LAB:
            return collecting_sample_testkit_transit_lab()
        if self is OrderStatus.SAMPLE_WITH_LAB_TESTKIT_DELIVERED_TO_LAB:
            return sample_with_lab_testkit_delivered_to_lab()
        if self is OrderStatus.COMPLETED_TESTKIT_COMPLETED:
            return completed_testkit_completed()
        if self is OrderStatus.FAILED_TESTKIT_FAILURE_TO_DELIVER_TO_CUSTOMER:
            return failed_testkit_failure_to_deliver_to_customer()
        if self is OrderStatus.FAILED_TESTKIT_FAILURE_TO_DELIVER_TO_LAB:
            return failed_testkit_failure_to_deliver_to_lab()
        if self is OrderStatus.FAILED_TESTKIT_SAMPLE_ERROR:
            return failed_testkit_sample_error()
        if self is OrderStatus.FAILED_TESTKIT_LOST:
            return failed_testkit_lost()
        if self is OrderStatus.CANCELLED_TESTKIT_CANCELLED:
            return cancelled_testkit_cancelled()
        if self is OrderStatus.CANCELLED_TESTKIT_DO_NOT_PROCESS:
            return cancelled_testkit_do_not_process()
        if self is OrderStatus.COLLECTING_SAMPLE_TESTKIT_PROBLEM_IN_TRANSIT_CUSTOMER:
            return collecting_sample_testkit_problem_in_transit_customer()
        if self is OrderStatus.COLLECTING_SAMPLE_TESTKIT_PROBLEM_IN_TRANSIT_LAB:
            return collecting_sample_testkit_problem_in_transit_lab()
